@@ -4,9 +4,8 @@
 
 chrome.test.runTests([function testEval() {
   window.foo = 2;
-  var exceptedExceptionMessage = 'Refused to evaluate a string as JavaScript ' +
-      'because \'unsafe-eval\' is not an allowed source of script in the ' +
-      'following Content Security Policy directive';
+  var exceptedExceptionMessage = 'Evaluating a string as JavaScript ' +
+      'violates the following Content Security Policy directive';
   chrome.test.assertThrows(
       eval, ['window.foo = 3;'], new RegExp(exceptedExceptionMessage));
   chrome.test.assertEq(2, window.foo);
