@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-chrome.browserAction.onClicked.addListener(() => {
+chrome.action.onClicked.addListener(() => {
   // We should be running with a user gesture.
   chrome.test.assertTrue(chrome.test.isProcessingUserGesture());
 
