@@ -3,7 +3,6 @@
 // found in the LICENSE file.
 
 import {AnnotationMode, PluginController, PluginControllerEventType, UserAction} from 'chrome-extension://mhjfbmdgcfjbbpaeojofohoefgiehjai/pdf_viewer_wrapper.js';
-import {assert} from 'chrome://resources/js/assert.js';
 import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
 import {eventToPromise, isVisible, microtasksFinished} from 'chrome://webui-test/test_util.js';
 
@@ -21,6 +20,18 @@ function getDownloadControls() {
   return getRequiredElement(viewerToolbar, 'viewer-download-controls');
 }
 
+function getFirstSaveMessageName(): string {
+  return loadTimeData.getBoolean('pdfGetSaveDataInBlocks') ?
+      'getSuggestedFileName' :
+      'save';
+}
+
+function getSaveRequestType(message: any): SaveRequestType {
+  return loadTimeData.getBoolean('pdfGetSaveDataInBlocks') ?
+      message.saveRequestTypeForTesting :
+      message.saveRequestType;
+}
+
 // Test saving with annotations. The download control's action menu should be
 // opened.
 async function testSaveWithAnnotations() {
@@ -29,21 +40,23 @@ async function testSaveWithAnnotations() {
 
   // The download menu should be shown.
   await eventToPromise('save-menu-shown-for-testing', downloadControls);
-  chrome.test.assertTrue(mockPlugin.findMessage('save') === undefined);
+  chrome.test.assertTrue(
+      mockPlugin.findMessage(getFirstSaveMessageName()) === undefined);
   chrome.test.assertTrue(actionMenu.open);
 
   const onSave = eventToPromise('save', viewer);
 
   // Click on "Edited".
   const buttons = actionMenu.querySelectorAll('button');
-  assert(buttons.length === 2);
+  chrome.test.assertEq(2, buttons.length);
   buttons[0]!.click();
 
   // A message should be sent to the plugin to save as annotated.
   await onSave;
-  const saveMessage = mockPlugin.findMessage('save');
+  const saveMessage = mockPlugin.findMessage(getFirstSaveMessageName());
   chrome.test.assertTrue(saveMessage !== undefined);
-  chrome.test.assertEq(saveMessage.saveRequestType, SaveRequestType.ANNOTATION);
+  chrome.test.assertEq(
+      getSaveRequestType(saveMessage), SaveRequestType.ANNOTATION);
   chrome.test.assertFalse(actionMenu.open);
 }
 
@@ -67,9 +80,10 @@ chrome.test.runTests([
 
     // A message should be sent to the plugin to save as original.
     await eventToPromise('save', viewer);
-    const saveMessage = mockPlugin.findMessage('save');
+    const saveMessage = mockPlugin.findMessage(getFirstSaveMessageName());
     chrome.test.assertTrue(saveMessage !== undefined);
-    chrome.test.assertEq(saveMessage.saveRequestType, SaveRequestType.ORIGINAL);
+    chrome.test.assertEq(
+        getSaveRequestType(saveMessage), SaveRequestType.ORIGINAL);
     chrome.test.assertFalse(actionMenu.open);
     chrome.test.assertEq(AnnotationMode.DRAW, viewerToolbar.annotationMode);
     mockMetricsPrivate.assertCount(UserAction.SAVE_ORIGINAL_ONLY, 1);
@@ -111,21 +125,23 @@ chrome.test.runTests([
 
     // The download menu should be shown.
     await eventToPromise('save-menu-shown-for-testing', downloadControls);
-    chrome.test.assertTrue(mockPlugin.findMessage('save') === undefined);
+    chrome.test.assertTrue(
+        mockPlugin.findMessage(getFirstSaveMessageName()) === undefined);
     chrome.test.assertTrue(actionMenu.open);
 
     const onSave = eventToPromise('save', viewer);
 
     // Click on "Original".
     const buttons = actionMenu.querySelectorAll('button');
-    assert(buttons.length === 2);
+    chrome.test.assertEq(2, buttons.length);
     buttons[1]!.click();
 
     // A message should be sent to the plugin to save as annotated.
     await onSave;
-    const saveMessage = mockPlugin.findMessage('save');
+    const saveMessage = mockPlugin.findMessage(getFirstSaveMessageName());
     chrome.test.assertTrue(saveMessage !== undefined);
-    chrome.test.assertEq(saveMessage.saveRequestType, SaveRequestType.ORIGINAL);
+    chrome.test.assertEq(
+        getSaveRequestType(saveMessage), SaveRequestType.ORIGINAL);
     chrome.test.assertFalse(actionMenu.open);
     mockMetricsPrivate.assertCount(UserAction.SAVE_ORIGINAL, 1);
     chrome.test.succeed();
@@ -185,9 +201,10 @@ chrome.test.runTests([
 
     // A message should be sent to the plugin to save as original.
     await eventToPromise('save', viewer);
-    const saveMessage = mockPlugin.findMessage('save');
+    const saveMessage = mockPlugin.findMessage(getFirstSaveMessageName());
     chrome.test.assertTrue(saveMessage !== undefined);
-    chrome.test.assertEq(saveMessage.saveRequestType, SaveRequestType.ORIGINAL);
+    chrome.test.assertEq(
+        getSaveRequestType(saveMessage), SaveRequestType.ORIGINAL);
     chrome.test.assertFalse(actionMenu.open);
     mockMetricsPrivate.assertCount(UserAction.SAVE_ORIGINAL_ONLY, 1);
     chrome.test.succeed();
@@ -213,7 +230,8 @@ chrome.test.runTests([
 
     // The download menu should be shown.
     await eventToPromise('save-menu-shown-for-testing', downloadControls);
-    chrome.test.assertTrue(mockPlugin.findMessage('save') === undefined);
+    chrome.test.assertTrue(
+        mockPlugin.findMessage(getFirstSaveMessageName()) === undefined);
     chrome.test.assertTrue(actionMenu.open);
     chrome.test.succeed();
   },
@@ -249,9 +267,10 @@ chrome.test.runTests([
 
     // A message should be sent to the plugin to save as original.
     await eventToPromise('save', viewer);
-    const saveMessage = mockPlugin.findMessage('save');
+    const saveMessage = mockPlugin.findMessage(getFirstSaveMessageName());
     chrome.test.assertTrue(saveMessage !== undefined);
-    chrome.test.assertEq(saveMessage.saveRequestType, SaveRequestType.ORIGINAL);
+    chrome.test.assertEq(
+        getSaveRequestType(saveMessage), SaveRequestType.ORIGINAL);
     chrome.test.assertFalse(actionMenu.open);
     mockMetricsPrivate.assertCount(UserAction.SAVE_ORIGINAL_ONLY, 1);
     chrome.test.succeed();
@@ -273,7 +292,7 @@ chrome.test.runTests([
     createTextBox();
     await microtasksFinished();
     const textbox = viewer.shadowRoot.querySelector('ink-text-box');
-    assert(textbox);
+    chrome.test.assertTrue(!!textbox);
     chrome.test.assertTrue(isVisible(textbox));
 
     const downloadControls = getDownloadControls();
@@ -285,9 +304,10 @@ chrome.test.runTests([
 
     // A message should be sent to the plugin to save as original.
     await eventToPromise('save', viewer);
-    const saveMessage = mockPlugin.findMessage('save');
+    const saveMessage = mockPlugin.findMessage(getFirstSaveMessageName());
     chrome.test.assertTrue(saveMessage !== undefined);
-    chrome.test.assertEq(saveMessage.saveRequestType, SaveRequestType.ORIGINAL);
+    chrome.test.assertEq(
+        getSaveRequestType(saveMessage), SaveRequestType.ORIGINAL);
     chrome.test.assertFalse(actionMenu.open);
     chrome.test.assertEq(AnnotationMode.TEXT, viewerToolbar.annotationMode);
     mockMetricsPrivate.assertCount(UserAction.SAVE_ORIGINAL_ONLY, 1);
@@ -311,7 +331,7 @@ chrome.test.runTests([
     createTextBox();
     await microtasksFinished();
     const textbox = viewer.shadowRoot.querySelector('ink-text-box');
-    assert(textbox);
+    chrome.test.assertTrue(!!textbox);
     chrome.test.assertTrue(isVisible(textbox));
     textbox.$.textbox.value = 'Hello';
     textbox.$.textbox.dispatchEvent(new CustomEvent('input'));
@@ -323,8 +343,8 @@ chrome.test.runTests([
     // Textbox is closed and annotation is committed.
     chrome.test.assertFalse(isVisible(textbox));
     // The finishTextAnnotation message should have been sent before save.
-    const saveIndex =
-        mockPlugin.messages.findIndex(message => message.type === 'save');
+    const saveIndex = mockPlugin.messages.findIndex(
+        message => message.type === getFirstSaveMessageName());
     const setTextIndex = mockPlugin.messages.findIndex(
         message => message.type === 'finishTextAnnotation');
     chrome.test.assertFalse(setTextIndex === -1);
@@ -366,9 +386,10 @@ chrome.test.runTests([
 
     // A message should be sent to the plugin to save as original.
     await eventToPromise('save', viewer);
-    const saveMessage = mockPlugin.findMessage('save');
+    const saveMessage = mockPlugin.findMessage(getFirstSaveMessageName());
     chrome.test.assertTrue(saveMessage !== undefined);
-    chrome.test.assertEq(saveMessage.saveRequestType, SaveRequestType.ORIGINAL);
+    chrome.test.assertEq(
+        getSaveRequestType(saveMessage), SaveRequestType.ORIGINAL);
     chrome.test.assertFalse(actionMenu.open);
     mockMetricsPrivate.assertCount(UserAction.SAVE_ORIGINAL_ONLY, 1);
     chrome.test.succeed();
