@@ -4,6 +4,7 @@
 
 import 'chrome-extension://mhjfbmdgcfjbbpaeojofohoefgiehjai/pdf_viewer_wrapper.js';
 
+import {SaveToDriveState} from 'chrome-extension://mhjfbmdgcfjbbpaeojofohoefgiehjai/pdf_viewer_wrapper.js';
 import {eventToPromise, microtasksFinished} from 'chrome://webui-test/test_util.js';
 
 const SaveRequestType = chrome.pdfViewerPrivate.SaveRequestType;
@@ -65,7 +66,7 @@ const tests = [
         !!element.shadowRoot.querySelector('circular-progress-ring'));
 
     // Once upload is in progress, the icon will change.
-    element.uploading = true;
+    element.state = SaveToDriveState.UPLOADING;
     element.progress = 10;
     await microtasksFinished();
     chrome.test.assertEq('pdf:arrow-upward-alt', element.$.save.ironIcon);
@@ -73,7 +74,7 @@ const tests = [
         !!element.shadowRoot.querySelector('circular-progress-ring'));
 
     // Once upload is reset, it should go back to the initial state.
-    element.uploading = false;
+    element.state = SaveToDriveState.UNINITIALIZED;
     await microtasksFinished();
     chrome.test.assertEq('pdf:add-to-drive', element.$.save.ironIcon);
     chrome.test.assertFalse(
@@ -81,6 +82,42 @@ const tests = [
 
     chrome.test.succeed();
   },
+
+  /**
+   * Test that the save menu only opens in UNINITIALIZED state when the save
+   * button is clicked.
+   */
+  async function testMenuOnSaveClick() {
+    document.body.innerHTML = window.trustedTypes!.emptyHTML;
+    const element = document.createElement('viewer-save-to-drive-controls');
+    element.hasEdits = true;
+    document.body.appendChild(element);
+    await microtasksFinished();
+
+    const statesToCheck = [
+      SaveToDriveState.UPLOADING,
+      SaveToDriveState.SUCCESS,
+      SaveToDriveState.CONNECTION_ERROR,
+      SaveToDriveState.STORAGE_FULL_ERROR,
+      SaveToDriveState.SESSION_TIMEOUT_ERROR,
+      SaveToDriveState.UNKNOWN_ERROR,
+    ];
+
+    for (const state of statesToCheck) {
+      element.state = state;
+      element.$.save.click();
+      await microtasksFinished();
+      chrome.test.assertFalse(element.$.menu.open);
+    }
+
+    // Once upload is reset, the menu should open.
+    element.state = SaveToDriveState.UNINITIALIZED;
+    element.$.save.click();
+    await eventToPromise('save-menu-shown-for-testing', element);
+    chrome.test.assertTrue(element.$.menu.open);
+
+    chrome.test.succeed();
+  },
 ];
 
 chrome.test.runTests(tests);
