@@ -143,7 +143,13 @@ IN_PROC_BROWSER_TEST_F(CrComponentsMostVisitedTest, General) {
   RunTest("cr_components/most_visited_test.js", "runMochaSuite('General');");
 }
 
-IN_PROC_BROWSER_TEST_F(CrComponentsMostVisitedTest, Layouts) {
+// TODO(https://crbug.com/449760234): Times out on linux debug builds.
+#if BUILDFLAG(IS_LINUX) && !defined(NDEBUG)
+#define MAYBE_Layouts DISABLED_Layouts
+#else
+#define MAYBE_Layouts Layouts
+#endif
+IN_PROC_BROWSER_TEST_F(CrComponentsMostVisitedTest, MAYBE_Layouts) {
   RunTest("cr_components/most_visited_test.js", "runMochaSuite('Layouts');");
 }
 
@@ -182,6 +188,16 @@ IN_PROC_BROWSER_TEST_F(CrComponentsMostVisitedTest, Theming) {
   RunTest("cr_components/most_visited_test.js", "runMochaSuite('Theming');");
 }
 
+IN_PROC_BROWSER_TEST_F(CrComponentsMostVisitedTest, ShowAddButton) {
+  RunTest("cr_components/most_visited_test.js",
+          "runMochaSuite('ShowAddButton');");
+}
+
+IN_PROC_BROWSER_TEST_F(CrComponentsMostVisitedTest, ShowMoreButton) {
+  RunTest("cr_components/most_visited_test.js",
+          "runMochaSuite('ShowMoreButton');");
+}
+
 typedef WebUIMochaBrowserTest CrComponentsThemeColorPickerTest;
 IN_PROC_BROWSER_TEST_F(CrComponentsThemeColorPickerTest, ThemeColor) {
   set_test_loader_host(chrome::kChromeUICustomizeChromeSidePanelHost);
