@@ -2,8 +2,9 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+import {TileSource} from '//resources/mojo/components/ntp_tiles/tile_source.mojom-webui.js';
 import {MostVisitedBrowserProxy} from 'chrome://resources/cr_components/most_visited/browser_proxy.js';
-import {MostVisitedElement} from 'chrome://resources/cr_components/most_visited/most_visited.js';
+import {MAX_TILES_FOR_CUSTOM_LINKS, MostVisitedElement} from 'chrome://resources/cr_components/most_visited/most_visited.js';
 import type {MostVisitedPageRemote, MostVisitedTile} from 'chrome://resources/cr_components/most_visited/most_visited.mojom-webui.js';
 import {MostVisitedPageCallbackRouter, MostVisitedPageHandlerRemote} from 'chrome://resources/cr_components/most_visited/most_visited.mojom-webui.js';
 import {MostVisitedWindowProxy} from 'chrome://resources/cr_components/most_visited/window_proxy.js';
@@ -19,6 +20,8 @@ import {isVisible, microtasksFinished} from 'chrome://webui-test/test_util.js';
 
 import {$$, assertStyle, keydown} from './most_visited_test_support.js';
 
+const MAX_TILES_BEFORE_SHOW_MORE = 5;
+
 let mostVisited: MostVisitedElement;
 let windowProxy: TestMock<MostVisitedWindowProxy>&MostVisitedWindowProxy;
 let handler: TestMock<MostVisitedPageHandlerRemote>&
@@ -38,6 +41,10 @@ function queryHiddenTiles(): HTMLAnchorElement[] {
   return queryAll<HTMLAnchorElement>('.tile[hidden]');
 }
 
+function getShowMoreButton(): CrButtonElement|null {
+  return $$<CrButtonElement>(mostVisited, '#showMore');
+}
+
 function assertTileLength(length: number) {
   assertEquals(length, queryTiles().length);
 }
@@ -151,15 +158,30 @@ function leaveUrlInput() {
   return microtasksFinished();
 }
 
-function setUpTest(singleRow: boolean, reflowOnOverflow: boolean) {
+interface SetUpTestOptions {
+  singleRow: boolean;
+  reflowOnOverflow: boolean;
+  enableShowMoreButton: boolean;
+}
+
+function setUpTest(providedOptions: Partial<SetUpTestOptions> = {}) {
+  const defaultOptions = {
+    singleRow: false,
+    reflowOnOverflow: false,
+    enableShowMoreButton: false,
+  };
+  const options = {...defaultOptions, ...providedOptions};
   document.body.innerHTML = window.trustedTypes!.emptyHTML;
 
   createBrowserProxy();
   createWindowProxy();
 
   mostVisited = new MostVisitedElement();
-  mostVisited.singleRow = singleRow;
-  mostVisited.reflowOnOverflow = reflowOnOverflow;
+  mostVisited.singleRow = options.singleRow;
+  mostVisited.reflowOnOverflow = options.reflowOnOverflow;
+  if (options.enableShowMoreButton) {
+    mostVisited.setAttribute('enable-show-more-button', '');
+  }
   document.body.appendChild(mostVisited);
   assertEquals(1, handler.getCallCount('updateMostVisitedInfo'));
   return wide();
@@ -167,7 +189,7 @@ function setUpTest(singleRow: boolean, reflowOnOverflow: boolean) {
 
 suite('General', () => {
   setup(async () => {
-    await setUpTest(/*singleRow=*/ false, /*reflowOnOverflow=*/ false);
+    await setUpTest();
   });
 
   test('empty shows add shortcut only', async () => {
@@ -201,9 +223,109 @@ suite('General', () => {
   });
 });
 
+suite('ShowAddButton', () => {
+  setup(async () => {
+    await setUpTest({reflowOnOverflow: true});
+  });
+
+  test('add shortcut button shows when custom links enabled', async () => {
+    await addTiles(0, /*customLinksEnabled=*/ true);
+    assertAddShortcutShown();
+  });
+
+  test('add shortcut button hidden when custom links disabled', async () => {
+    await addTiles(0, /*customLinksEnabled=*/ false);
+    assertAddShortcutHidden();
+  });
+
+  test(
+      'add shortcut button hidden when custom links disabled and max tiles',
+      async () => {
+        const tiles = Array(MAX_TILES_FOR_CUSTOM_LINKS).fill(0).map((_x, i) => {
+          const char = String.fromCharCode(i + /* 'a' */ 97);
+          return {
+            title: char,
+            titleDirection: TextDirection.LEFT_TO_RIGHT,
+            url: {url: `https://${char}/`},
+            source: i % 2 === 0 ? TileSource.TOP_SITES :
+                                  TileSource.CUSTOM_LINKS,
+            titleSource: i,
+            isQueryTile: false,
+            allowUserEdit: true,
+            allowUserDelete: true,
+          };
+        });
+        await addTiles(tiles, /*customLinksEnabled=*/ true);
+        assertAddShortcutHidden();
+      });
+
+  test(
+      'add shortcut button shown when custom links disabled and max enterprise tiles',
+      async () => {
+        const tiles = Array(MAX_TILES_FOR_CUSTOM_LINKS).fill(0).map((_x, i) => {
+          const char = String.fromCharCode(i + /* 'a' */ 97);
+          return {
+            title: char,
+            titleDirection: TextDirection.LEFT_TO_RIGHT,
+            url: {url: `https://${char}/`},
+            source: TileSource.ENTERPRISE_SHORTCUTS,
+            titleSource: i,
+            isQueryTile: false,
+            allowUserEdit: true,
+            allowUserDelete: true,
+          };
+        });
+        await addTiles(
+            tiles, /*customLinksEnabled=*/ true, /*visible=*/ true,
+            /*enterpriseShortcutsEnabled=*/ true);
+        assertAddShortcutShown();
+      });
+});
+
+suite('ShowMoreButton', () => {
+  suiteSetup(() => {
+    loadTimeData.overrideValues({
+      maxTilesBeforeShowMore: MAX_TILES_BEFORE_SHOW_MORE,
+    });
+  });
+
+  test('Show more button is shown with 6 or more tiles', async () => {
+    await setUpTest({reflowOnOverflow: true, enableShowMoreButton: true});
+    await addTiles(MAX_TILES_BEFORE_SHOW_MORE + 1);
+    assertTrue(isVisible(getShowMoreButton()));
+    assertAddShortcutHidden();
+    assertHiddenTileLength(0);
+  });
+
+  test('Show more button is hidden with 5 or fewer tiles', async () => {
+    await setUpTest({reflowOnOverflow: true, enableShowMoreButton: true});
+    await addTiles(MAX_TILES_BEFORE_SHOW_MORE);
+    assertFalse(isVisible(getShowMoreButton()));
+    assertAddShortcutShown();
+  });
+
+  test(
+      'Clicking the show more button shows all tiles and hides the button',
+      async () => {
+        await setUpTest({reflowOnOverflow: true, enableShowMoreButton: true});
+        await addTiles(MAX_TILES_BEFORE_SHOW_MORE + 2);  // 7 tiles.
+        const showMoreButton = getShowMoreButton();
+        assertTrue(isVisible(showMoreButton));
+        assertAddShortcutHidden();
+        assertHiddenTileLength(1);  // 7 tiles, 6 visible, so 1 hidden.
+
+        showMoreButton!.click();
+        await microtasksFinished();
+
+        assertFalse(isVisible(getShowMoreButton()));
+        assertAddShortcutShown();
+        assertHiddenTileLength(0);
+      });
+});
+
 function createLayoutsSuite(singleRow: boolean, reflowOnOverflow: boolean) {
   setup(async () => {
-    await setUpTest(singleRow, reflowOnOverflow);
+    await setUpTest({singleRow, reflowOnOverflow});
   });
 
   test('four tiles fit on one line with addShortcut', async () => {
@@ -335,7 +457,7 @@ function createLayoutsSuite(singleRow: boolean, reflowOnOverflow: boolean) {
 function createLayoutsWidthsSuite(singleRow: boolean) {
   suite('test various widths', () => {
     setup(async () => {
-      await setUpTest(singleRow, false);
+      await setUpTest({singleRow});
     });
 
     test('six / three is max for narrow', async () => {
@@ -444,7 +566,7 @@ function columnCount(): number {
 function createLayoutsWidthsReflowSuite(singleRow: boolean) {
   suite('test reflow on various widths', () => {
     setup(async () => {
-      await setUpTest(singleRow, /*reflowOnOverflow=*/ true);
+      await setUpTest({singleRow, reflowOnOverflow: true});
     });
 
     test('No hidden tiles', async () => {
@@ -514,7 +636,7 @@ suite('Reflow Layouts', () => {
 
 suite('LoggingAndUpdates', () => {
   setup(async () => {
-    await setUpTest(/*singleRow=*/ false, /*reflowOnOverflow=*/ false);
+    await setUpTest();
   });
 
   test('rendering tiles logs event', async () => {
@@ -605,7 +727,7 @@ suite('Modification', () => {
   });
 
   setup(async () => {
-    await setUpTest(/*singleRow=*/ false, /*reflowOnOverflow=*/ false);
+    await setUpTest();
   });
 
   suite('add dialog', () => {
@@ -930,7 +1052,7 @@ suite('Modification', () => {
     assertFalse(mostVisited.$.toastManager.isToastOpen);
     removeButton.click();
     assertFalse(actionMenu.open);
-    assertEquals('https://b/', (await deleteCalled).url);
+    assertEquals('https://b/', (await deleteCalled).url.url);
     assertTrue(mostVisited.$.toastManager.isToastOpen);
     // Toast buttons are visible.
     assertTrue(isVisible($$(mostVisited, '#undo')));
@@ -958,7 +1080,7 @@ suite('Modification', () => {
     const deleteCalled = handler.whenCalled('deleteMostVisitedTile');
     assertFalse(mostVisited.$.toastManager.isToastOpen);
     removeButton.click();
-    assertEquals('https://search-url/', (await deleteCalled).url);
+    assertEquals('https://search-url/', (await deleteCalled).url.url);
     assertTrue(mostVisited.$.toastManager.isToastOpen);
     // Toast buttons are visible.
     assertTrue(isVisible($$(mostVisited, '#undo')));
@@ -972,7 +1094,7 @@ suite('Modification', () => {
     const deleteCalled = handler.whenCalled('deleteMostVisitedTile');
     assertFalse(mostVisited.$.toastManager.isToastOpen);
     removeButton.click();
-    assertEquals('https://a/', (await deleteCalled).url);
+    assertEquals('https://a/', (await deleteCalled).url.url);
     assertTrue(mostVisited.$.toastManager.isToastOpen);
     // Toast buttons are visible.
     assertTrue(isVisible($$(mostVisited, '#undo')));
@@ -997,7 +1119,7 @@ suite('Modification', () => {
     const deleteCalled = handler.whenCalled('deleteMostVisitedTile');
     assertFalse(mostVisited.$.toastManager.isToastOpen);
     removeButton.click();
-    assertEquals('https://search-url/', (await deleteCalled).url);
+    assertEquals('https://search-url/', (await deleteCalled).url.url);
     assertTrue(mostVisited.$.toastManager.isToastOpen);
     // Toast buttons are not visible.
     assertFalse(isVisible($$(mostVisited, '#undo')));
@@ -1016,7 +1138,7 @@ suite('Modification', () => {
     const deleteCalled = handler.whenCalled('deleteMostVisitedTile');
     assertFalse(mostVisited.$.toastManager.isToastOpen);
     keydown(tile, 'Delete');
-    assertEquals('https://a/', (await deleteCalled).url);
+    assertEquals('https://a/', (await deleteCalled).url.url);
     assertTrue(mostVisited.$.toastManager.isToastOpen);
   });
 
@@ -1110,7 +1232,7 @@ suite('Modification', () => {
 
 function createDragAndDropSuite(singleRow: boolean, reflowOnOverflow: boolean) {
   setup(async () => {
-    await setUpTest(singleRow, reflowOnOverflow);
+    await setUpTest({singleRow, reflowOnOverflow});
   });
 
   test('drag first tile to second position', async () => {
@@ -1138,8 +1260,8 @@ function createDragAndDropSuite(singleRow: boolean, reflowOnOverflow: boolean) {
       clientY: secondRect.y + 1,
     }));
     await mostVisited.updateComplete;
-    const [url, newPos] = await reorderCalled;
-    assertEquals('https://a/', url.url);
+    const [tile, newPos] = await reorderCalled;
+    assertEquals('https://a/', tile.url.url);
     assertEquals(1, newPos);
     const [newFirst, newSecond] = queryTiles();
     assertEquals('https://b/', newFirst!.querySelector('a')!.href);
@@ -1171,8 +1293,8 @@ function createDragAndDropSuite(singleRow: boolean, reflowOnOverflow: boolean) {
       clientY: firstRect.y + 1,
     }));
     await mostVisited.updateComplete;
-    const [url, newPos] = await reorderCalled;
-    assertEquals('https://b/', url.url);
+    const [tile, newPos] = await reorderCalled;
+    assertEquals('https://b/', tile.url.url);
     assertEquals(0, newPos);
     const [newFirst, newSecond] = queryTiles();
     assertEquals('https://b/', newFirst!.querySelector('a')!.href);
@@ -1208,6 +1330,188 @@ function createDragAndDropSuite(singleRow: boolean, reflowOnOverflow: boolean) {
     assertEquals('https://a/', newFirst!.querySelector('a')!.href);
     assertEquals('https://b/', newSecond!.querySelector('a')!.href);
   });
+
+  test('new index is adjusted by enterprise shortcuts', async () => {
+    const enterpriseShortcut = {
+      title: 'e1',
+      titleDirection: TextDirection.LEFT_TO_RIGHT,
+      url: {url: `https://e1/`},
+      source: TileSource.ENTERPRISE_SHORTCUTS,
+      titleSource: 0,
+      isQueryTile: false,
+      allowUserEdit: true,
+      allowUserDelete: true,
+    };
+    const customLink1 = {
+      title: 'c1',
+      titleDirection: TextDirection.LEFT_TO_RIGHT,
+      url: {url: `https://c1/`},
+      source: TileSource.CUSTOM_LINKS,
+      titleSource: 1,
+      isQueryTile: false,
+      allowUserEdit: true,
+      allowUserDelete: true,
+    };
+    const customLink2 = {
+      title: 'c2',
+      titleDirection: TextDirection.LEFT_TO_RIGHT,
+      url: {url: `https://c2/`},
+      source: TileSource.CUSTOM_LINKS,
+      titleSource: 2,
+      isQueryTile: false,
+      allowUserEdit: true,
+      allowUserDelete: true,
+    };
+    await addTiles(
+        [enterpriseShortcut, customLink1, customLink2],
+        /*customLinksEnabled=*/ true, /*visible=*/ true,
+        /*enterpriseShortcutsEnabled=*/ true);
+
+    const tiles = queryTiles();
+    const customLink1Element = tiles[1]!;
+    const customLink2Element = tiles[2]!;
+
+    const customLink1Rect = customLink1Element.getBoundingClientRect();
+    const customLink2Rect = customLink2Element.getBoundingClientRect();
+
+    // Drag customLink1 (index 1) to customLink2's position (index 2).
+    customLink1Element.dispatchEvent(new DragEvent('dragstart', {
+      clientX: customLink1Rect.x + customLink1Rect.width / 2,
+      clientY: customLink1Rect.y + customLink1Rect.height / 2,
+    }));
+
+    const reorderCalled = handler.whenCalled('reorderMostVisitedTile');
+
+    document.dispatchEvent(new DragEvent('drop', {
+      clientX: customLink2Rect.x + 1,
+      clientY: customLink2Rect.y + 1,
+    }));
+    document.dispatchEvent(new DragEvent('dragend', {
+      clientX: customLink2Rect.x + 1,
+      clientY: customLink2Rect.y + 1,
+    }));
+    await mostVisited.updateComplete;
+
+    const [tile, newPos] = await reorderCalled;
+    assertEquals('https://c1/', tile.url.url);
+    // Expected new position: original index of c1 in custom group (0) + 1
+    // (because it moved past c2 in the custom group).
+    // The dropIndex is 2, but there is 1 enterprise shortcut, so 2 - 1 = 1.
+    assertEquals(1, newPos);
+
+    const [newEnterprise, newCustom2, newCustom1] = queryTiles();
+    assertEquals('https://e1/', newEnterprise!.querySelector('a')!.href);
+    assertEquals('https://c2/', newCustom2!.querySelector('a')!.href);
+    assertEquals('https://c1/', newCustom1!.querySelector('a')!.href);
+  });
+
+  test('cannot drag custom link to enterprise shortcut position', async () => {
+    const enterpriseShortcut = {
+      title: 'a',
+      titleDirection: TextDirection.LEFT_TO_RIGHT,
+      url: {url: `https://a/`},
+      source: TileSource.ENTERPRISE_SHORTCUTS,
+      titleSource: 0,
+      isQueryTile: false,
+      allowUserEdit: true,
+      allowUserDelete: true,
+    };
+    const customLink = {
+      title: 'b',
+      titleDirection: TextDirection.LEFT_TO_RIGHT,
+      url: {url: `https://b/`},
+      source: TileSource.CUSTOM_LINKS,
+      titleSource: 1,
+      isQueryTile: false,
+      allowUserEdit: true,
+      allowUserDelete: true,
+    };
+    await addTiles(
+        [enterpriseShortcut, customLink],
+        /*customLinksEnabled=*/ true, /*visible=*/ true,
+        /*enterpriseShortcutsEnabled=*/ true);
+
+    const tiles = queryTiles();
+    const first = tiles[0]!;
+    const second = tiles[1]!;
+    assertEquals('https://a/', first.querySelector('a')!.href);
+    assertTrue(first.draggable);
+    assertEquals('https://b/', second.querySelector('a')!.href);
+    assertTrue(second.draggable);
+    const firstRect = first.getBoundingClientRect();
+    const secondRect = second.getBoundingClientRect();
+    second.dispatchEvent(new DragEvent('dragstart', {
+      clientX: secondRect.x + secondRect.width / 2,
+      clientY: secondRect.y + secondRect.height / 2,
+    }));
+    document.dispatchEvent(new DragEvent('drop', {
+      clientX: firstRect.x + 1,
+      clientY: firstRect.y + 1,
+    }));
+    document.dispatchEvent(new DragEvent('dragend', {
+      clientX: firstRect.x + 1,
+      clientY: firstRect.y + 1,
+    }));
+    await mostVisited.updateComplete;
+    assertEquals(0, handler.getCallCount('reorderMostVisitedTile'));
+    const [newFirst, newSecond] = queryTiles();
+    assertEquals('https://a/', newFirst!.querySelector('a')!.href);
+    assertEquals('https://b/', newSecond!.querySelector('a')!.href);
+  });
+
+  test('cannot drag enterprise shortcut to custom link position', async () => {
+    const enterpriseShortcut = {
+      title: 'a',
+      titleDirection: TextDirection.LEFT_TO_RIGHT,
+      url: {url: `https://a/`},
+      source: TileSource.ENTERPRISE_SHORTCUTS,
+      titleSource: 0,
+      isQueryTile: false,
+      allowUserEdit: true,
+      allowUserDelete: true,
+    };
+    const customLink = {
+      title: 'b',
+      titleDirection: TextDirection.LEFT_TO_RIGHT,
+      url: {url: `https://b/`},
+      source: TileSource.CUSTOM_LINKS,
+      titleSource: 1,
+      isQueryTile: false,
+      allowUserEdit: true,
+      allowUserDelete: true,
+    };
+    await addTiles(
+        [enterpriseShortcut, customLink],
+        /*customLinksEnabled=*/ true, /*visible=*/ true,
+        /*enterpriseShortcutsEnabled=*/ true);
+
+    const tiles = queryTiles();
+    const first = tiles[0]!;
+    const second = tiles[1]!;
+    assertEquals('https://a/', first.querySelector('a')!.href);
+    assertTrue(first.draggable);
+    assertEquals('https://b/', second.querySelector('a')!.href);
+    assertTrue(second.draggable);
+    const firstRect = first.getBoundingClientRect();
+    const secondRect = second.getBoundingClientRect();
+    first.dispatchEvent(new DragEvent('dragstart', {
+      clientX: firstRect.x + firstRect.width / 2,
+      clientY: firstRect.y + firstRect.height / 2,
+    }));
+    document.dispatchEvent(new DragEvent('drop', {
+      clientX: secondRect.x + 1,
+      clientY: secondRect.y + 1,
+    }));
+    document.dispatchEvent(new DragEvent('dragend', {
+      clientX: secondRect.x + 1,
+      clientY: secondRect.y + 1,
+    }));
+    await mostVisited.updateComplete;
+    assertEquals(0, handler.getCallCount('reorderMostVisitedTile'));
+    const [newFirst, newSecond] = queryTiles();
+    assertEquals('https://a/', newFirst!.querySelector('a')!.href);
+    assertEquals('https://b/', newSecond!.querySelector('a')!.href);
+  });
 }
 
 suite('DragAndDrop', () => {
@@ -1223,7 +1527,7 @@ suite('DragAndDrop', () => {
 
 suite('Theming', () => {
   setup(async () => {
-    await setUpTest(/*singleRow=*/ false, /*reflowOnOverflow=*/ false);
+    await setUpTest();
   });
 
   test('RIGHT_TO_LEFT tile title text direction', async () => {
@@ -1290,7 +1594,7 @@ suite('Preloading', () => {
   suiteSetup(() => {});
 
   setup(async () => {
-    await setUpTest(/*singleRow=*/ false, /*reflowOnOverflow=*/ false);
+    await setUpTest();
   });
 
   test('onMouseHover Trigger', async () => {
@@ -1337,7 +1641,7 @@ suite('EnterpriseShortcuts', () => {
   suiteSetup(() => {});
 
   setup(async () => {
-    await setUpTest(/*singleRow=*/ false, /*reflowOnOverflow=*/ false);
+    await setUpTest();
   });
 
   function createEnterpriseShortcut(
@@ -1348,7 +1652,7 @@ suite('EnterpriseShortcuts', () => {
       title: char,
       titleDirection: TextDirection.LEFT_TO_RIGHT,
       url: {url: `https://${char}/`},
-      source: i,
+      source: TileSource.ENTERPRISE_SHORTCUTS,
       titleSource: i,
       isQueryTile: false,
       allowUserEdit: allowUserEdit,
@@ -1382,7 +1686,7 @@ suite('EnterpriseShortcuts', () => {
     assertEquals(
         'Edit shortcut',
         mostVisited.$.dialog.querySelector(
-                                '[slot="title"]')!.textContent!.trim());
+                                '[slot="title"]')!.textContent.trim());
     const policySubtitleContainer =
         mostVisited.$.dialog.querySelector<HTMLElement>(
             '#policySubtitleContainer');
@@ -1419,7 +1723,7 @@ suite('EnterpriseShortcuts', () => {
     assertEquals(
         'Shortcut',
         mostVisited.$.dialog.querySelector(
-                                '[slot="title"]')!.textContent!.trim());
+                                '[slot="title"]')!.textContent.trim());
     const policySubtitleContainer =
         mostVisited.$.dialog.querySelector<HTMLElement>(
             '#policySubtitleContainer');
@@ -1467,7 +1771,7 @@ suite('EnterpriseShortcuts', () => {
     let viewOrEditButton =
         $$<HTMLButtonElement>(mostVisited, '#actionMenuViewOrEdit');
     assertFalse(viewOrEditButton.disabled);
-    assertEquals('Edit shortcut', viewOrEditButton.textContent!.trim());
+    assertEquals('Edit shortcut', viewOrEditButton.textContent.trim());
     assertFalse(
         $$<HTMLButtonElement>(mostVisited, '#actionMenuRemove').disabled);
     mostVisited.$.actionMenu.close();
@@ -1481,7 +1785,7 @@ suite('EnterpriseShortcuts', () => {
     viewOrEditButton =
         $$<HTMLButtonElement>(mostVisited, '#actionMenuViewOrEdit');
     assertFalse(viewOrEditButton.disabled);
-    assertEquals('Edit shortcut', viewOrEditButton.textContent!.trim());
+    assertEquals('Edit shortcut', viewOrEditButton.textContent.trim());
     assertTrue(
         $$<HTMLButtonElement>(mostVisited, '#actionMenuRemove').disabled);
     mostVisited.$.actionMenu.close();
@@ -1495,7 +1799,7 @@ suite('EnterpriseShortcuts', () => {
     viewOrEditButton =
         $$<HTMLButtonElement>(mostVisited, '#actionMenuViewOrEdit');
     assertFalse(viewOrEditButton.disabled);
-    assertEquals('Details', viewOrEditButton.textContent!.trim());
+    assertEquals('Details', viewOrEditButton.textContent.trim());
     assertFalse(
         $$<HTMLButtonElement>(mostVisited, '#actionMenuRemove').disabled);
     mostVisited.$.actionMenu.close();
@@ -1509,7 +1813,7 @@ suite('EnterpriseShortcuts', () => {
     viewOrEditButton =
         $$<HTMLButtonElement>(mostVisited, '#actionMenuViewOrEdit');
     assertFalse(viewOrEditButton.disabled);
-    assertEquals('Details', viewOrEditButton.textContent!.trim());
+    assertEquals('Details', viewOrEditButton.textContent.trim());
     assertTrue(
         $$<HTMLButtonElement>(mostVisited, '#actionMenuRemove').disabled);
   });
