@@ -227,6 +227,10 @@ IN_PROC_BROWSER_TEST_F(LensOverlayTest, Searchbox) {
   RunOverlayTest("lens/overlay/searchbox_test.js", "mocha.run()");
 }
 
+IN_PROC_BROWSER_TEST_F(LensOverlayTest, ReshowOverlay) {
+  RunOverlayTest("lens/overlay/reshow_overlay_test.js", "mocha.run()");
+}
+
 #if defined(UNDEFINED_SANITIZER)
 #define MAYBE_TranslateButton DISABLED_TranslateButton
 #else
