@@ -3,7 +3,8 @@
 // found in the LICENSE file.
 
 import type {CustomizeButtonsDocumentRemote} from 'chrome://new-tab-page/customize_buttons.mojom-webui.js';
-import {CustomizeButtonsDocumentCallbackRouter, CustomizeButtonsHandlerRemote, CustomizeChromeSection, SidePanelOpenTrigger} from 'chrome://new-tab-page/customize_buttons.mojom-webui.js';
+import {CustomizeButtonsDocumentCallbackRouter, CustomizeButtonsHandlerRemote, SidePanelOpenTrigger} from 'chrome://new-tab-page/customize_buttons.mojom-webui.js';
+import {CustomizeChromeSection} from 'chrome://new-tab-page/customize_chrome.mojom-webui.js';
 import type {Module} from 'chrome://new-tab-page/lazy_load.js';
 import {ComposeboxProxyImpl, counterfactualLoad, ModuleDescriptor, ModuleRegistry} from 'chrome://new-tab-page/lazy_load.js';
 import {$$, BackgroundManager, BrowserCommandProxy, CUSTOMIZE_CHROME_BUTTON_ELEMENT_ID, CustomizeButtonsProxy, CustomizeDialogPage, NewTabPageProxy, NtpCustomizeChromeEntryPoint, NtpElement, SearchboxBrowserProxy, VoiceAction, WindowProxy} from 'chrome://new-tab-page/new_tab_page.js';
@@ -400,9 +401,9 @@ suite('NewTabPageAppTest', () => {
           'https://info.com',
           $$(app, '#backgroundImageAttribution')!.getAttribute('href'));
       assertEquals(
-          'foo', $$(app, '#backgroundImageAttribution1')!.textContent!.trim());
+          'foo', $$(app, '#backgroundImageAttribution1')!.textContent.trim());
       assertEquals(
-          'bar', $$(app, '#backgroundImageAttribution2')!.textContent!.trim());
+          'bar', $$(app, '#backgroundImageAttribution2')!.textContent.trim());
     });
 
     test('setting logo color colors logo', async function() {
@@ -1224,7 +1225,7 @@ suite('NewTabPageAppTest', () => {
       await microtasksFinished();
 
       // Assert.
-      const composebox = app.shadowRoot.querySelector('ntp-composebox');
+      const composebox = app.shadowRoot.querySelector('cr-composebox');
       assertTrue(!!composebox);
       assertStyle($$(app, '#searchbox')!, 'visibility', 'hidden');
     });
@@ -1248,7 +1249,7 @@ suite('NewTabPageAppTest', () => {
           await microtasksFinished();
 
           // Assert.
-          const composebox = app.shadowRoot.querySelector('ntp-composebox');
+          const composebox = app.shadowRoot.querySelector('cr-composebox');
           assertTrue(!!composebox);
           assertEquals(
               searchboxHandler.getCallCount('notifySessionStarted'), 1);
@@ -1269,7 +1270,7 @@ suite('NewTabPageAppTest', () => {
           await microtasksFinished();
 
           // Assert.
-          const composebox = app.shadowRoot.querySelector('ntp-composebox');
+          const composebox = app.shadowRoot.querySelector('cr-composebox');
           assertTrue(!!composebox);
           assertEquals(
               searchboxHandler.getCallCount('notifySessionStarted'), 1);
@@ -1310,13 +1311,13 @@ suite('NewTabPageAppTest', () => {
               detail: {searchboxText: '', contextFiles: []},
             }));
             await microtasksFinished();
-            const ntpComposebox =
-                app.shadowRoot.querySelector('ntp-composebox');
-            ntpComposebox!.setText('hello');
+            const composebox =
+                app.shadowRoot.querySelector('cr-composebox');
+            composebox!.setText('hello');
             const composeboxScrim =
                 app.shadowRoot.querySelector<HTMLElement>('#scrim');
             assertTrue(!!composeboxScrim);
-            assertEquals(ntpComposebox!.getText(), 'hello');
+            assertEquals(composebox!.getText(), 'hello');
             composeboxScrim.click();
             await microtasksFinished();
 
@@ -1351,7 +1352,7 @@ suite('NewTabPageAppTest', () => {
           bubbles: true,
           cancelable: true,
         });
-        const composebox = app.shadowRoot.querySelector('ntp-composebox');
+        const composebox = app.shadowRoot.querySelector('cr-composebox');
         assertTrue(!!composebox);
         composebox.dispatchEvent(escapeKeyEvent);
         await microtasksFinished();
@@ -1889,21 +1890,21 @@ suite('NewTabPageAppTest', () => {
             detail: {searchboxText: '', contextFiles: []},
           }));
           await microtasksFinished();
-          const ntpComposebox = app.shadowRoot.querySelector('ntp-composebox');
-          assertTrue(!!ntpComposebox);
-          ntpComposebox.$.input.dispatchEvent(new FocusEvent('focus'));
+          const composebox = app.shadowRoot.querySelector('cr-composebox');
+          assertTrue(!!composebox);
+          composebox.$.input.dispatchEvent(new FocusEvent('focus'));
           await microtasksFinished();
 
           assertFalse(scrim.hidden);
 
-          ntpComposebox.$.input.dispatchEvent(
+          composebox.$.input.dispatchEvent(
               new FocusEvent('focusout', {relatedTarget: scrim}));
           await microtasksFinished();
           scrim.click();
           await microtasksFinished();
           assertTrue(scrim?.hidden);
           // Composebox should have been closed.
-          assertFalse(!!app.shadowRoot.querySelector('ntp-composebox'));
+          assertFalse(!!app.shadowRoot.querySelector('cr-composebox'));
         });
     test('searchbox text carries over to composebox', async () => {
         // Arrange.
@@ -1918,7 +1919,7 @@ suite('NewTabPageAppTest', () => {
       await microtasksFinished();
 
       // Assert.
-      const composebox = app.shadowRoot.querySelector('ntp-composebox');
+      const composebox = app.shadowRoot.querySelector('cr-composebox');
       assertTrue(!!composebox);
       assertEquals(
         'text',
@@ -1926,4 +1927,20 @@ suite('NewTabPageAppTest', () => {
       assertStyle($$(app, '#searchbox')!, 'visibility', 'hidden');
     });
   });
+
+  suite('ActionChips', () => {
+    [true, false].forEach(
+        (ntpNextFeaturesEnabled) =>
+            suite(`actionChips rendered ${ntpNextFeaturesEnabled}`, () => {
+              suiteSetup(() => {
+                loadTimeData.overrideValues({ntpNextFeaturesEnabled});
+              });
+
+              test('Show iframe when appropriate', () => {
+                const chips = $$<HTMLElement>(app, 'ntp-action-chips');
+
+                assertEquals(!!chips, ntpNextFeaturesEnabled);
+              });
+            }));
+  });
 });
