@@ -2,12 +2,12 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+import type {SelectedFileInfo} from '//resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
 import {ComposeboxElement, ComposeboxProxyImpl} from 'chrome://new-tab-page/lazy_load.js';
 import {$$} from 'chrome://new-tab-page/new_tab_page.js';
 import {PageCallbackRouter, PageHandlerRemote} from 'chrome://resources/cr_components/composebox/composebox.mojom-webui.js';
 import {FileUploadErrorType, FileUploadStatus} from 'chrome://resources/cr_components/composebox/composebox_query.mojom-webui.js';
 import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
-import {stringToMojoString16} from 'chrome://resources/js/mojo_type_util.js';
 import {PageCallbackRouter as SearchboxPageCallbackRouter, PageHandlerRemote as SearchboxPageHandlerRemote} from 'chrome://resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
 import type {AutocompleteMatch, AutocompleteResult, PageRemote as SearchboxPageRemote} from 'chrome://resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
 import {assertDeepEquals, assertEquals, assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
@@ -24,6 +24,7 @@ enum Attributes {
 
 const ADD_FILE_CONTEXT_FN = 'addFileContext';
 const ADD_TAB_CONTEXT_FN = 'addTabContext';
+const FAKE_TOKEN_STRING = '00000000000000001234567890ABCDEF';
 
 function generateZeroId(): string {
   // Generate 128 bit unique identifier.
@@ -110,7 +111,7 @@ suite('NewTabPageComposeboxTest', () => {
 
   function createAutocompleteMatch(): AutocompleteMatch {
     return {
-      a11yLabel: {data: []},
+      a11yLabel: '',
       actions: [],
       allowedToBeDefaultMatch: false,
       isSearchType: false,
@@ -118,19 +119,19 @@ suite('NewTabPageComposeboxTest', () => {
       swapContentsAndDescription: false,
       supportsDeletion: false,
       suggestionGroupId: -1,  // Indicates a missing suggestion group Id.
-      contents: {data: []},
+      contents: '',
       contentsClass: [{offset: 0, style: 0}],
-      description: {data: []},
+      description: '',
       descriptionClass: [{offset: 0, style: 0}],
       destinationUrl: {url: ''},
-      inlineAutocompletion: {data: []},
-      fillIntoEdit: {data: []},
+      inlineAutocompletion: '',
+      fillIntoEdit: '',
       iconPath: '',
       iconUrl: {url: ''},
       imageDominantColor: '',
       imageUrl: '',
       isNoncannedAimSuggestion: false,
-      removeButtonA11yLabel: {data: []},
+      removeButtonA11yLabel: '',
       type: '',
       isRichSuggestion: false,
       isWeatherAnswerSuggestion: null,
@@ -145,7 +146,7 @@ suite('NewTabPageComposeboxTest', () => {
   function createAutocompleteResult(
       modifiers: Partial<AutocompleteResult> = {}): AutocompleteResult {
     const base: AutocompleteResult = {
-      input: stringToMojoString16(''),
+      input: '',
       matches: [],
       suggestionGroupsMap: {},
       smartComposeInlineHint: null,
@@ -159,9 +160,9 @@ suite('NewTabPageComposeboxTest', () => {
     return Object.assign(
         createAutocompleteMatch(), {
           isSearchType: true,
-          contents: stringToMojoString16('hello world'),
+          contents: 'hello world',
           destinationUrl: {url: 'https://www.google.com/search?q=hello+world'},
-          fillIntoEdit: stringToMojoString16('hello world'),
+          fillIntoEdit: 'hello world',
           type: 'search-suggest',
         },
         modifiers);
@@ -609,6 +610,88 @@ suite('NewTabPageComposeboxTest', () => {
     assertTrue(event.defaultPrevented);
   });
 
+  test('set and delete visual selection thumbnail', async () => {
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Initially, carousel is not shown.
+    assertFalse(composeboxElement.hasAttribute('show-file-carousel_'));
+
+    // Set a thumbnail.
+    const thumbnailUrl = 'data:image/png;base64,sometestdata';
+    searchboxCallbackRouterRemote.addFileContext(FAKE_TOKEN_STRING, {
+      fileName: 'Visual Selection',
+      mimeType: 'image/png',
+      imageDataUrl: thumbnailUrl,
+      isDeletable: true,
+      selectionTime: new Date(),
+    } as SelectedFileInfo);
+    await microtasksFinished();
+
+    // Assert thumbnail is shown.
+    assertTrue(composeboxElement.hasAttribute('show-file-carousel_'));
+    const fileCarousel = composeboxElement.$.context.$.carousel;
+    assertTrue(!!fileCarousel);
+    await microtasksFinished();
+
+    assertEquals(fileCarousel.files.length, 1);
+    assertDeepEquals(fileCarousel.files[0]!.uuid, FAKE_TOKEN_STRING);
+    assertEquals(fileCarousel.files[0]!.dataUrl, thumbnailUrl);
+    assertTrue(fileCarousel.files[0]!.isDeletable);
+
+    // Delete the thumbnail.
+    const fileThumbnail =
+        fileCarousel.shadowRoot.querySelector('cr-composebox-file-thumbnail');
+    assertTrue(!!fileThumbnail);
+
+    const removeImgButton =
+        fileThumbnail.shadowRoot.querySelector<HTMLElement>('#removeImgButton');
+    assertTrue(!!removeImgButton);
+    removeImgButton.click();
+    await microtasksFinished();
+
+    // Assert thumbnail is removed.
+    assertEquals(searchboxHandler.getCallCount('deleteContext'), 1);
+    const [idArg] = searchboxHandler.getArgs('deleteContext');
+    assertEquals(idArg, FAKE_TOKEN_STRING);
+    // The carousel is removed from the DOM when there are no files, so
+    // assert its absence.
+    assertFalse(
+        !!composeboxElement.$.context.shadowRoot.querySelector('#carousel'));
+    assertFalse(composeboxElement.hasAttribute('show-file-carousel_'));
+  });
+
+  test('setVisualSelectionThumbnail not deletable', async () => {
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Set a thumbnail that is not deletable.
+    const thumbnailUrl = 'data:image/png;base64,sometestdata';
+    searchboxCallbackRouterRemote.addFileContext(FAKE_TOKEN_STRING, {
+      fileName: 'Visual Selection',
+      mimeType: 'image/png',
+      imageDataUrl: thumbnailUrl,
+      isDeletable: false,
+      selectionTime: new Date(),
+    } as SelectedFileInfo);
+    await microtasksFinished();
+
+    // Assert thumbnail is shown.
+    assertTrue(composeboxElement.hasAttribute('show-file-carousel_'));
+    const fileCarousel = composeboxElement.$.context.$.carousel;
+    assertTrue(!!fileCarousel);
+    assertEquals(fileCarousel.files.length, 1);
+    assertFalse(fileCarousel.files[0]!.isDeletable);
+
+    // Assert delete button is not present.
+    const fileThumbnail =
+        fileCarousel.shadowRoot.querySelector('cr-composebox-file-thumbnail');
+    assertTrue(!!fileThumbnail);
+    const removeButton =
+        fileThumbnail.shadowRoot.querySelector<HTMLElement>('#removeImgButton');
+    assertEquals(null, removeButton);
+  });
+
   test('image upload button clicks file input', async () => {
     loadTimeData.overrideValues({
       'composeboxShowContextMenu': false,
@@ -762,7 +845,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     const matches = [
       createSearchMatch(),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({matches}));
@@ -770,7 +853,7 @@ suite('NewTabPageComposeboxTest', () => {
     assertTrue(await areMatchesShowing());
     const matchEls =
         composeboxElement.$.matches.shadowRoot.querySelectorAll(
-            'ntp-composebox-match');
+            'cr-composebox-match');
 
     // Case 1: composeboxCloseByEscape_ = false. Escape should select the
     // first suggestion.
@@ -824,7 +907,7 @@ suite('NewTabPageComposeboxTest', () => {
     const matches = [createSearchMatch({allowedToBeDefaultMatch: true})];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16('test'),
+          input: 'test',
           matches,
         }));
     await searchboxCallbackRouterRemote.$.flushForTesting();
@@ -869,7 +952,7 @@ suite('NewTabPageComposeboxTest', () => {
     const matches = [createSearchMatch({allowedToBeDefaultMatch: true})];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16('test'),
+          input: 'test',
           matches: matches,
         }));
     await searchboxCallbackRouterRemote.$.flushForTesting();
@@ -946,7 +1029,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     const matches = [
       createSearchMatch(),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
@@ -976,7 +1059,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     const matches = [
       createSearchMatch(),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
@@ -1018,7 +1101,7 @@ suite('NewTabPageComposeboxTest', () => {
     // Add matches and verify dropdown shows.
     const matches = [
       createSearchMatch(),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
@@ -1053,15 +1136,15 @@ suite('NewTabPageComposeboxTest', () => {
 
     const matches = [
       createSearchMatch(
-          {fillIntoEdit: stringToMojoString16('hello world 1'), allowedToBeDefaultMatch: true}),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 3')}),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 4')}),
+          {fillIntoEdit: 'hello world 1', allowedToBeDefaultMatch: true}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
+      createSearchMatch({fillIntoEdit: 'hello world 3'}),
+      createSearchMatch({fillIntoEdit: 'hello world 4'}),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
           matches: matches,
-          input: stringToMojoString16('Test'),
+          input: 'Test',
         }));
     await microtasksFinished();
 
@@ -1069,7 +1152,7 @@ suite('NewTabPageComposeboxTest', () => {
     assertFalse(composeboxDropdown.hidden);
 
     const matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
-        'ntp-composebox-match');
+        'cr-composebox-match');
     assertEquals(4, matchEls.length);
     const matchEl = matchEls[0];
     assertTrue(!!matchEl);
@@ -1133,7 +1216,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     const matches = [
       createSearchMatch(),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
@@ -1153,80 +1236,6 @@ suite('NewTabPageComposeboxTest', () => {
     assertTrue(composeboxDropdown.hidden);
   });
 
-  test('dropdown does not show for typed suggest with context', async () => {
-    loadTimeData.overrideValues(
-        {composeboxShowZps: true, composeboxShowTypedSuggest: true});
-    createComposeboxElement();
-    await microtasksFinished();
-
-    // Add typed input.
-    composeboxElement.$.input.value = 'Test';
-    composeboxElement.$.input.dispatchEvent(new Event('input'));
-    await microtasksFinished();
-
-    const composeboxDropdown =
-        composeboxElement.shadowRoot.querySelector<HTMLElement>('#matches');
-    assertTrue(!!composeboxDropdown);
-
-    const matches = [
-      createSearchMatch({
-        fillIntoEdit: stringToMojoString16('hello world 1'),
-        allowedToBeDefaultMatch: true,
-      }),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 3')}),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 4')}),
-    ];
-    searchboxCallbackRouterRemote.autocompleteResultChanged(
-        createAutocompleteResult({
-          matches: matches,
-          input: stringToMojoString16('Test'),
-        }));
-    await microtasksFinished();
-
-    // Dropdown should show for when matches are available.
-    assertFalse(composeboxDropdown.hidden);
-
-    // If context files are added, the dropdown should no longer be visible.
-    composeboxElement.$.context.dispatchEvent(
-        new CustomEvent('on-context-files-changed', {
-          detail: {files: 1},
-        }));
-    await microtasksFinished();
-    assertTrue(composeboxDropdown.hidden);
-  });
-
-  test(
-      'dropdown does not show for typed suggest with verbatim match only',
-      async () => {
-        loadTimeData.overrideValues(
-            {composeboxShowZps: true, composeboxShowTypedSuggest: true});
-        createComposeboxElement();
-        await microtasksFinished();
-
-        // Add typed input.
-        composeboxElement.$.input.value = 'Test';
-        composeboxElement.$.input.dispatchEvent(new Event('input'));
-        await microtasksFinished();
-
-        const composeboxDropdown =
-            composeboxElement.shadowRoot.querySelector<HTMLElement>('#matches');
-        assertTrue(!!composeboxDropdown);
-
-        const matches = [
-          createSearchMatch(),
-        ];
-        searchboxCallbackRouterRemote.autocompleteResultChanged(
-            createAutocompleteResult({
-              matches: matches,
-              input: stringToMojoString16('Test'),
-            }));
-        await microtasksFinished();
-
-        // Dropdown should not show when only the verbatim match is present.
-        assertTrue(composeboxDropdown.hidden);
-      });
-
   test('notify browser when image is added in create image mode', async () => {
     loadTimeData.overrideValues({
       composeboxShowZps: true,
@@ -1272,6 +1281,42 @@ suite('NewTabPageComposeboxTest', () => {
     assertEquals(handler.getCallCount('setCreateImageMode'), 3);
   });
 
+  test(
+      'dropdown visibility change fires an event when Realbox Next is enabled',
+      async () => {
+        loadTimeData.overrideValues({
+          composeboxShowZps: true,
+          composeboxShowTypedSuggest: true,
+        });
+        createComposeboxElement();
+        composeboxElement.ntpRealboxNextEnabled = true;
+
+        let whenDropdownVisibleChanged = eventToPromise(
+            'composebox-dropdown-visible-changed', composeboxElement);
+
+        // Add typed input.
+        composeboxElement.$.input.value = 'Test';
+        composeboxElement.$.input.style.height = '48px';
+        composeboxElement.$.input.dispatchEvent(new Event('input'));
+        await microtasksFinished();
+        const matches = [
+          createSearchMatch(),
+        ];
+        searchboxCallbackRouterRemote.autocompleteResultChanged(
+            createAutocompleteResult({
+              input: 'Test',
+              matches: matches,
+            }));
+        const e1 = await whenDropdownVisibleChanged;
+        assertTrue(e1.detail.value);
+
+        whenDropdownVisibleChanged = eventToPromise(
+            'composebox-dropdown-visible-changed', composeboxElement);
+        composeboxElement.closeDropdown();
+        const e2 = await whenDropdownVisibleChanged;
+        assertFalse(e2.detail.value);
+      });
+
   test('arrow up/down moves selection / focus', async () => {
     loadTimeData.overrideValues({composeboxShowZps: true});
     createComposeboxElement();
@@ -1283,7 +1328,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     const matches = [
       createSearchMatch(),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
@@ -1293,7 +1338,7 @@ suite('NewTabPageComposeboxTest', () => {
     assertTrue(await areMatchesShowing());
 
     const matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
-        'ntp-composebox-match');
+        'cr-composebox-match');
     assertEquals(2, matchEls.length);
 
     const arrowDownEvent = new KeyboardEvent('keydown', {
@@ -1363,15 +1408,14 @@ suite('NewTabPageComposeboxTest', () => {
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input:
-              stringToMojoString16(composeboxElement.$.input.value.trimStart()),
+          input: composeboxElement.$.input.value.trimStart(),
           matches,
         }));
     await microtasksFinished();
     assertTrue(await areMatchesShowing());
 
     let matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
-        'ntp-composebox-match');
+        'cr-composebox-match');
     assertEquals(1, matchEls.length);
     // First match is not selected.
     assertFalse(matchEls[0]!.hasAttribute(Attributes.SELECTED));
@@ -1385,20 +1429,21 @@ suite('NewTabPageComposeboxTest', () => {
     searchboxHandler.reset();
 
     matches = [
-      createSearchMatch({supportsDeletion: true}), createSearchMatch({
+      createSearchMatch({supportsDeletion: true}),
+      createSearchMatch({
         supportsDeletion: true,
-        fillIntoEdit: stringToMojoString16('hello world 2'),
+        fillIntoEdit: 'hello world 2',
       }),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16(''),
+          input: '',
           matches: matches,
         }));
     assertTrue(await areMatchesShowing());
 
     matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
-        'ntp-composebox-match');
+        'cr-composebox-match');
     assertEquals(2, matchEls.length);
 
     // First match is not selected.
@@ -1437,11 +1482,11 @@ suite('NewTabPageComposeboxTest', () => {
 
     matches = [createSearchMatch({
       supportsDeletion: true,
-      fillIntoEdit: stringToMojoString16('hello world 2'),
+      fillIntoEdit: 'hello world 2',
     })];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16(''),
+          input: '',
           matches: matches,
         }));
     assertTrue(await areMatchesShowing());
@@ -1460,9 +1505,9 @@ suite('NewTabPageComposeboxTest', () => {
 
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16('smart '),
+          input: 'smart ',
           matches: [],
-          smartComposeInlineHint: stringToMojoString16('compose'),
+          smartComposeInlineHint: 'compose',
         }));
     await microtasksFinished();
 
@@ -1484,9 +1529,9 @@ suite('NewTabPageComposeboxTest', () => {
 
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16('smart '),
+          input: 'smart ',
           matches: [],
-          smartComposeInlineHint: stringToMojoString16('compose'),
+          smartComposeInlineHint: 'compose',
         }));
     await microtasksFinished();
 
@@ -1513,7 +1558,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     const matches = [
       createSearchMatch(),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
     ];
 
     // Add typed input
@@ -1521,9 +1566,9 @@ suite('NewTabPageComposeboxTest', () => {
     composeboxElement.$.input.dispatchEvent(new Event('input'));
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16('awesome'),
+          input: 'awesome',
           matches: matches,
-          smartComposeInlineHint: stringToMojoString16('compose'),
+          smartComposeInlineHint: 'compose',
         }));
     assertTrue(await areMatchesShowing());
 
@@ -1573,7 +1618,7 @@ suite('NewTabPageComposeboxTest', () => {
     const matches = [createSearchMatch()];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16(''),
+          input: '',
           matches,
         }));
     assertTrue(await areMatchesShowing());
@@ -1608,7 +1653,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     const matches = [
       createSearchMatch(),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
@@ -1617,7 +1662,7 @@ suite('NewTabPageComposeboxTest', () => {
     assertTrue(await areMatchesShowing());
 
     let matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
-        'ntp-composebox-match');
+        'cr-composebox-match');
     assertEquals(2, matchEls.length);
     let matchEl = matchEls[0];
     assertTrue(!!matchEl);
@@ -1629,13 +1674,13 @@ suite('NewTabPageComposeboxTest', () => {
     composeboxElement.$.input.dispatchEvent(new Event('input'));
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16('awesome'),
+          input: 'awesome',
           matches: matches,
         }));
     assertTrue(await areMatchesShowing());
 
     matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
-        'ntp-composebox-match');
+        'cr-composebox-match');
     assertEquals(2, matchEls.length);
     matchEl = matchEls[0];
     assertTrue(!!matchEl);
@@ -1650,11 +1695,11 @@ suite('NewTabPageComposeboxTest', () => {
 
     const matches = [
       createSearchMatch(),
-      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+      createSearchMatch({fillIntoEdit: 'hello world 2'}),
     ];
     searchboxCallbackRouterRemote.autocompleteResultChanged(
         createAutocompleteResult({
-          input: stringToMojoString16(''),
+          input: '',
           matches,
           suggestionGroupsMap: {},
         }));
@@ -1662,7 +1707,7 @@ suite('NewTabPageComposeboxTest', () => {
     assertTrue(await areMatchesShowing());
 
     const matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
-        'ntp-composebox-match');
+        'cr-composebox-match');
     assertEquals(2, matchEls.length);
     const matchEl = matchEls[0];
     assertTrue(!!matchEl);
