@@ -239,17 +239,19 @@ suite('GlicSubpage', function() {
       assertFalse($<SettingsToggleButtonElement>('tabAccessToggle')!.checked);
     });
 
-    test('TabContextToggleChange', () => {
+    test('TabContextToggleChange', async () => {
       page.setPrefValue(PrefName.TAB_CONTEXT_ENABLED, false);
 
       const tabAccessToggle = $<SettingsToggleButtonElement>('tabAccessToggle');
       assertTrue(!!tabAccessToggle);
 
-      tabAccessToggle.click();
+      tabAccessToggle.$.control.click();
+      await flushTasks();
       assertTrue(page.getPref(PrefName.TAB_CONTEXT_ENABLED).value);
       assertTrue(tabAccessToggle.checked);
 
-      tabAccessToggle.click();
+      tabAccessToggle.$.control.click();
+      await flushTasks();
       assertFalse(page.getPref(PrefName.TAB_CONTEXT_ENABLED).value);
       assertFalse(tabAccessToggle.checked);
     });
@@ -327,7 +329,7 @@ suite('GlicSubpage', function() {
       // Toggles should all have values from the real pref and be enabled.
       let toggles = page.shadowRoot!.querySelectorAll(
           'settings-toggle-button[checked]:not([disabled])');
-      assertEquals(5, toggles.length);
+      assertEquals(6, toggles.length);
 
       await setDisallowedByAdminAndSimulateUpdate(true);
 
@@ -341,7 +343,7 @@ suite('GlicSubpage', function() {
 
       toggles = page.shadowRoot!.querySelectorAll(
           'settings-toggle-button:not([checked])[disabled]');
-      assertEquals(4, toggles.length);
+      assertEquals(6, toggles.length);
 
       // Re-enable the policy, the page should go back to the initial state.
       await setDisallowedByAdminAndSimulateUpdate(false);
@@ -353,7 +355,7 @@ suite('GlicSubpage', function() {
 
       toggles = page.shadowRoot!.querySelectorAll(
           'settings-toggle-button[checked]:not([disabled])');
-      assertEquals(5, toggles.length);
+      assertEquals(6, toggles.length);
     });
 
     test('ManageActivityRow', async () => {
@@ -477,10 +479,13 @@ suite('GlicSubpage', function() {
             $<SettingsToggleButtonElement>('tabAccessToggle')!;
         assertTrue(!!tabAccessToggle);
 
-        tabAccessToggle.click();
+        tabAccessToggle.$.control.click();
+        await flushTasks();
         await verifyUserAction('Glic.Settings.TabContext.Enabled');
 
-        tabAccessToggle.click();
+
+        tabAccessToggle.$.control.click();
+        await flushTasks();
         await verifyUserAction('Glic.Settings.TabContext.Disabled');
       });
     });
@@ -538,20 +543,6 @@ suite('GlicSubpage', function() {
     });
   });
 
-  suite('TabAccessToggleLearnMoreEnabled', () => {
-    test('tabAccessToggleLearnMoreShown', async () => {
-      const learnMoreElement =
-          page.shadowRoot!.querySelector<HTMLElement>('#tabAccessToggle')!
-              .shadowRoot!.querySelector<HTMLAnchorElement>('#learn-more');
-      assertTrue(!!learnMoreElement);
-      assertEquals(learnMoreElement.href, 'https://google.com/');
-
-      learnMoreElement.click();
-      await assertFeatureInteractionMetrics(
-          AiPageActions.GLIC_SHORTCUTS_TAB_ACCESS_TOGGLE_LEARN_MORE_CLICKED);
-    });
-  });
-
   suite('ClosedCaptionsToggleEnabled', () => {
     test('ClosedCaptionsToggleFeatureEnabled', () => {
       const closedCaptionsToggle =
@@ -673,6 +664,99 @@ suite('GlicSubpage', function() {
     });
   });
 
+  suite('WebActuationSettingFeatureEnabled', () => {
+    test('WebActuationSettingFeatureEnabled', () => {
+      const webActuationToggle =
+          $<SettingsToggleButtonElement>('webActuationToggle')!;
+      assertTrue(isVisible(webActuationToggle));
+    });
+
+    test('ToggleEnabled', () => {
+      page.setPrefValue(PrefName.WEB_ACTUATION_ENABLED, true);
+
+      assertTrue($<SettingsToggleButtonElement>('webActuationToggle')!.checked);
+    });
+
+    test('ToggleDisabled', () => {
+      page.setPrefValue(PrefName.WEB_ACTUATION_ENABLED, false);
+
+      assertFalse(
+          $<SettingsToggleButtonElement>('webActuationToggle')!.checked);
+    });
+
+    test('WebActuationExpand', async () => {
+      const webActuationToggle =
+          $<SettingsToggleButtonElement>('webActuationToggle')!;
+      const infoCard = $<CrCollapseElement>('webActuationInfoCollapse')!;
+      page.setPrefValue(PrefName.WEB_ACTUATION_ENABLED, false);
+
+      assertFalse(infoCard.opened);
+
+      // Clicking the host element of the toggle button expands the info card
+      // but does not change the pref.
+      webActuationToggle.click();
+      await flushTasks();
+      assertTrue(infoCard.opened);
+      assertFalse(page.getPref(PrefName.WEB_ACTUATION_ENABLED).value);
+
+      // Clicking the host element again collapses the info card.
+      webActuationToggle.click();
+      await flushTasks();
+      assertFalse(infoCard.opened);
+      assertFalse(page.getPref(PrefName.WEB_ACTUATION_ENABLED).value);
+
+      // Toggling the setting to on expands the info card.
+      webActuationToggle.$.control.click();
+      await flushTasks();
+      assertTrue(page.getPref(PrefName.WEB_ACTUATION_ENABLED).value);
+      assertTrue(infoCard.opened);
+      await verifyUserAction('Glic.Settings.WebActuation.Enabled');
+
+      // Toggling the setting off collapses the info card.
+      webActuationToggle.$.control.click();
+      await flushTasks();
+      assertFalse(page.getPref(PrefName.WEB_ACTUATION_ENABLED).value);
+      assertFalse(infoCard.opened);
+      await verifyUserAction('Glic.Settings.WebActuation.Disabled');
+
+      // Toggling the setting to on while the info card is open leaves it open.
+      webActuationToggle.click();
+      await flushTasks();
+      assertTrue(infoCard.opened);
+      webActuationToggle.$.control.click();
+      await flushTasks();
+      assertTrue(page.getPref(PrefName.WEB_ACTUATION_ENABLED).value);
+      assertTrue(infoCard.opened);
+
+      // Toggling the setting to off while the info card is closed leaves it
+      // closed.
+      webActuationToggle.click();
+      await flushTasks();
+      assertFalse(infoCard.opened);
+      webActuationToggle.$.control.click();
+      await flushTasks();
+      assertFalse(page.getPref(PrefName.WEB_ACTUATION_ENABLED).value);
+      assertFalse(infoCard.opened);
+    });
+  });
+
+
+  suite('WebActuationToggleVisibleForAllowedTier', () => {
+    test('assert toggle is visible', () => {
+      const webActuationToggle =
+          $<SettingsToggleButtonElement>('webActuationToggle')!;
+      assertTrue(isVisible(webActuationToggle));
+    });
+  });
+
+  suite('WebActuationToggleHiddenForDisallowedTier', () => {
+    test('assert toggle is hidden', () => {
+      const webActuationToggle =
+          $<SettingsToggleButtonElement>('webActuationToggle')!;
+      assertFalse(isVisible(webActuationToggle));
+    });
+  });
+
   suite('DataProtection_UserStatusCheckEnabled', () => {
     test('DataProtectionStringsShownForEligibleUser', () => {
       page.setPrefValue(
@@ -694,8 +778,6 @@ suite('GlicSubpage', function() {
       assertEquals(
           page.i18n('glicTabAccessToggleSublabelDataProtected'),
           tabAccessToggle.subLabel);
-      assertEquals(
-          'https://example.com/data-protection', tabAccessToggle.learnMoreUrl);
       const learnMoreLabel =
           $<HTMLAnchorElement>('shortcutTabAccessConsider1LearnMoreLabel')!;
       assertEquals('https://example.com/data-protection', learnMoreLabel.href);
@@ -720,8 +802,6 @@ suite('GlicSubpage', function() {
           $<SettingsToggleButtonElement>('tabAccessToggle')!;
       assertEquals(
           page.i18n('glicTabAccessToggleSublabel'), tabAccessToggle.subLabel);
-      assertEquals(
-          'https://example.com/tab-access', tabAccessToggle.learnMoreUrl);
       const learnMoreLabel =
           $<HTMLAnchorElement>('shortcutTabAccessConsider1LearnMoreLabel')!;
       assertEquals('https://example.com/tab-access', learnMoreLabel.href);
@@ -748,8 +828,6 @@ suite('GlicSubpage', function() {
           $<SettingsToggleButtonElement>('tabAccessToggle')!;
       assertEquals(
           page.i18n('glicTabAccessToggleSublabel'), tabAccessToggle.subLabel);
-      assertEquals(
-          'https://example.com/tab-access', tabAccessToggle.learnMoreUrl);
       const learnMoreLabel =
           $<HTMLAnchorElement>('shortcutTabAccessConsider1LearnMoreLabel')!;
       assertEquals('https://example.com/tab-access', learnMoreLabel.href);
