@@ -7,11 +7,11 @@ import 'chrome://webui-test/cr_elements/cr_policy_strings.js';
 
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import type {SiteDetailsPermissionElement} from 'chrome://settings/lazy_load.js';
-import {ChooserType, ContentSetting, ContentSettingsTypes, SiteSettingSource, SiteSettingsPrefsBrowserProxyImpl} from 'chrome://settings/lazy_load.js';
+import {ChooserType, ContentSetting, ContentSettingsTypes, SiteSettingSource, SiteSettingsBrowserProxyImpl} from 'chrome://settings/lazy_load.js';
 import {assertDeepEquals, assertEquals, assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import {webUIListenerCallback} from 'chrome://resources/js/cr.js';
 
-import {TestSiteSettingsPrefsBrowserProxy} from './test_site_settings_prefs_browser_proxy.js';
+import {TestSiteSettingsBrowserProxy} from './test_site_settings_browser_proxy.js';
 import type {SiteSettingsPref} from './test_util.js';
 import {createContentSettingTypeToValuePair, createDefaultContentSetting, createRawChooserException, createRawSiteException, createSiteSettingsPrefs} from './test_util.js';
 // clang-format on
@@ -26,7 +26,7 @@ suite('SiteDetailsPermission', function() {
   /**
    * The mock proxy object to use during test.
    */
-  let browserProxy: TestSiteSettingsPrefsBrowserProxy;
+  let browserProxy: TestSiteSettingsBrowserProxy;
 
   /**
    * An example pref with only camera allowed.
@@ -44,8 +44,8 @@ suite('SiteDetailsPermission', function() {
             ContentSettingsTypes.CAMERA,
             [createRawSiteException('https://www.example.com')])]);
 
-    browserProxy = new TestSiteSettingsPrefsBrowserProxy();
-    SiteSettingsPrefsBrowserProxyImpl.setInstance(browserProxy);
+    browserProxy = new TestSiteSettingsBrowserProxy();
+    SiteSettingsBrowserProxyImpl.setInstance(browserProxy);
     document.body.innerHTML = window.trustedTypes!.emptyHTML;
     testElement = document.createElement('site-details-permission');
     document.body.appendChild(testElement);
@@ -66,6 +66,26 @@ suite('SiteDetailsPermission', function() {
     assertEquals(expectedContentSetting, setting);
   }
 
+  async function verifyDefaultOptionText(
+      contentSetting: ContentSetting, contentType: ContentSettingsTypes,
+      expectedOptionText: string) {
+    browserProxy.resetResolver('getDefaultValueForContentType');
+    const defaultPrefs = createSiteSettingsPrefs(
+        [createContentSettingTypeToValuePair(
+            contentType,
+            createDefaultContentSetting({setting: contentSetting}))],
+        []);
+    browserProxy.setPrefs(defaultPrefs);
+
+    const args = await browserProxy.whenCalled('getDefaultValueForContentType');
+    assertEquals(contentType, args);
+
+    // The default option will always be the first in the menu.
+    assertEquals(
+        expectedOptionText, testElement.$.permission.options[0]!.text,
+        'Default setting string should match prefs');
+  }
+
   test('camera category', async function() {
     const origin = 'https://www.example.com';
     browserProxy.setPrefs(prefs);
@@ -104,41 +124,45 @@ suite('SiteDetailsPermission', function() {
       source: SiteSettingSource.PREFERENCE,
     });
 
-    let args = await browserProxy.whenCalled('getDefaultValueForContentType');
-    // Check getDefaultValueForContentType was called for camera category.
-    assertEquals(ContentSettingsTypes.CAMERA, args);
-
-    // The default option will always be the first in the menu.
-    assertEquals(
-        'Allow (default)', testElement.$.permission.options[0]!.text,
-        'Default setting string should match prefs');
-    browserProxy.resetResolver('getDefaultValueForContentType');
-    let defaultPrefs = createSiteSettingsPrefs(
-        [createContentSettingTypeToValuePair(
-            ContentSettingsTypes.CAMERA,
-            createDefaultContentSetting({setting: ContentSetting.BLOCK}))],
-        []);
-    browserProxy.setPrefs(defaultPrefs);
-
-    args = await browserProxy.whenCalled('getDefaultValueForContentType');
-    assertEquals(ContentSettingsTypes.CAMERA, args);
-    assertEquals(
-        'Block (default)', testElement.$.permission.options[0]!.text,
-        'Default setting string should match prefs');
-    browserProxy.resetResolver('getDefaultValueForContentType');
-    defaultPrefs = createSiteSettingsPrefs(
-        [createContentSettingTypeToValuePair(
-            ContentSettingsTypes.CAMERA, createDefaultContentSetting())],
-        []);
-    browserProxy.setPrefs(defaultPrefs);
-
-    args = await browserProxy.whenCalled('getDefaultValueForContentType');
-    assertEquals(ContentSettingsTypes.CAMERA, args);
-    assertEquals(
-        'Ask (default)', testElement.$.permission.options[0]!.text,
-        'Default setting string should match prefs');
+    await verifyDefaultOptionText(
+        ContentSetting.ALLOW, ContentSettingsTypes.CAMERA, 'Allow (default)');
+    await verifyDefaultOptionText(
+        ContentSetting.BLOCK, ContentSettingsTypes.CAMERA, 'Block (default)');
+    await verifyDefaultOptionText(
+        ContentSetting.ASK, ContentSettingsTypes.CAMERA, 'Ask (default)');
   });
 
+  test(
+      'javascript optimizer category default string is correct',
+      async function() {
+        const origin = 'https://www.example.com';
+        browserProxy.setPrefs(prefs);
+        testElement.category = ContentSettingsTypes.JAVASCRIPT_OPTIMIZER;
+        testElement.label = 'JavaScript Optimizer';
+        testElement.site = createRawSiteException(origin, {
+          origin: origin,
+          embeddingOrigin: '',
+          setting: ContentSetting.ALLOW,
+          source: SiteSettingSource.PREFERENCE,
+        });
+        testElement.useBlockIfUnfamiliarLabelForDefault = true;
+
+        await verifyDefaultOptionText(
+            ContentSetting.ALLOW, ContentSettingsTypes.JAVASCRIPT_OPTIMIZER,
+            'Block if site is unfamiliar (default)');
+        await verifyDefaultOptionText(
+            ContentSetting.BLOCK, ContentSettingsTypes.JAVASCRIPT_OPTIMIZER,
+            'Block if site is unfamiliar (default)');
+
+        testElement.useBlockIfUnfamiliarLabelForDefault = false;
+        await verifyDefaultOptionText(
+            ContentSetting.ALLOW, ContentSettingsTypes.JAVASCRIPT_OPTIMIZER,
+            'Allow (default)');
+        await verifyDefaultOptionText(
+            ContentSetting.BLOCK, ContentSettingsTypes.JAVASCRIPT_OPTIMIZER,
+            'Block (default)');
+      });
+
   test('info string is correct', function() {
     const origin = 'https://www.example.com';
     testElement.category = ContentSettingsTypes.CAMERA;
@@ -404,41 +428,15 @@ suite('SiteDetailsPermission', function() {
       source: SiteSettingSource.PREFERENCE,
     });
 
-    let args = await browserProxy.whenCalled('getDefaultValueForContentType');
-    // Check getDefaultValueForContentType was called for sound category.
-    assertEquals(ContentSettingsTypes.SOUND, args);
+    await verifyDefaultOptionText(
+        ContentSetting.ALLOW, ContentSettingsTypes.SOUND, 'Allow (default)');
+    await verifyDefaultOptionText(
+        ContentSetting.BLOCK, ContentSettingsTypes.SOUND, 'Mute (default)');
 
-    // The default option will always be the first in the menu.
-    assertEquals(
-        'Allow (default)', testElement.$.permission.options[0]!.text,
-        'Default setting string should match prefs');
-    browserProxy.resetResolver('getDefaultValueForContentType');
-    let defaultPrefs = createSiteSettingsPrefs(
-        [createContentSettingTypeToValuePair(
-            ContentSettingsTypes.SOUND,
-            createDefaultContentSetting({setting: ContentSetting.BLOCK}))],
-        []);
-    browserProxy.setPrefs(defaultPrefs);
-
-    args = await browserProxy.whenCalled('getDefaultValueForContentType');
-    assertEquals(ContentSettingsTypes.SOUND, args);
-    assertEquals(
-        'Mute (default)', testElement.$.permission.options[0]!.text,
-        'Default setting string should match prefs');
-    browserProxy.resetResolver('getDefaultValueForContentType');
     testElement.useAutomaticLabel = true;
-    defaultPrefs = createSiteSettingsPrefs(
-        [createContentSettingTypeToValuePair(
-            ContentSettingsTypes.SOUND,
-            createDefaultContentSetting({setting: ContentSetting.ALLOW}))],
-        []);
-    browserProxy.setPrefs(defaultPrefs);
-
-    args = await browserProxy.whenCalled('getDefaultValueForContentType');
-    assertEquals(ContentSettingsTypes.SOUND, args);
-    assertEquals(
-        'Automatic (default)', testElement.$.permission.options[0]!.text,
-        'Default setting string should match prefs');
+    await verifyDefaultOptionText(
+        ContentSetting.ALLOW, ContentSettingsTypes.SOUND,
+        'Automatic (default)');
   });
 
   test('sound setting block string is correct', async function() {
@@ -653,7 +651,7 @@ suite('SiteDetailsPermission', function() {
     const firstDeviceDisplayName =
         deviceEntries[0]!.shadowRoot!.querySelector('.url-directionality');
     assertTrue(!!firstDeviceDisplayName);
-    assertEquals('Reader 1', firstDeviceDisplayName.textContent!.trim());
+    assertEquals('Reader 1', firstDeviceDisplayName.textContent.trim());
     assertFalse(!!deviceEntries[0]!.shadowRoot!.querySelector(
         'cr-policy-pref-indicator'));
     assertFalse(deviceEntries[0]!.$.resetSite.hidden);
@@ -662,7 +660,7 @@ suite('SiteDetailsPermission', function() {
     const secondDeviceDisplayName =
         deviceEntries[1]!.shadowRoot!.querySelector('.url-directionality');
     assertTrue(!!secondDeviceDisplayName);
-    assertEquals('All readers', secondDeviceDisplayName.textContent!.trim());
+    assertEquals('All readers', secondDeviceDisplayName.textContent.trim());
     assertTrue(!!deviceEntries[1]!.shadowRoot!.querySelector(
         'cr-policy-pref-indicator'));
     assertTrue(deviceEntries[1]!.$.resetSite.hidden);
@@ -722,7 +720,7 @@ suite('SiteDetailsPermission', function() {
     const firstDeviceDisplayName =
         deviceEntries[0]!.shadowRoot!.querySelector('.url-directionality');
     assertTrue(!!firstDeviceDisplayName);
-    assertEquals(firstDeviceDisplayName.textContent!.trim(), 'Gadget');
+    assertEquals(firstDeviceDisplayName.textContent.trim(), 'Gadget');
     assertFalse(!!deviceEntries[0]!.shadowRoot!.querySelector(
         'cr-policy-pref-indicator'));
     assertFalse(deviceEntries[0]!.$.resetSite.hidden);
@@ -731,7 +729,7 @@ suite('SiteDetailsPermission', function() {
     const secondDeviceDisplayName =
         deviceEntries[1]!.shadowRoot!.querySelector('.url-directionality');
     assertTrue(!!secondDeviceDisplayName);
-    assertEquals(secondDeviceDisplayName.textContent!.trim(), 'Gizmo');
+    assertEquals(secondDeviceDisplayName.textContent.trim(), 'Gizmo');
     assertTrue(!!deviceEntries[1]!.shadowRoot!.querySelector(
         'cr-policy-pref-indicator'));
     assertTrue(deviceEntries[1]!.$.resetSite.hidden);
@@ -827,7 +825,7 @@ suite('SiteDetailsPermission', function() {
         const deviceDisplayName =
             deviceEntries[0].shadowRoot!.querySelector('.url-directionality');
         assertTrue(!!deviceDisplayName);
-        assertEquals(deviceDisplayName.textContent!.trim(), 'Gadget');
+        assertEquals(deviceDisplayName.textContent.trim(), 'Gadget');
         assertFalse(!!deviceEntries[0].shadowRoot!.querySelector(
             'cr-policy-pref-indicator'));
         assertFalse(deviceEntries[0].$.resetSite.hidden);
