@@ -7,15 +7,14 @@ import {isChromeOS} from 'chrome://resources/js/platform.js';
 import {webUIListenerCallback} from 'chrome://resources/js/cr.js';
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import type {SiteDetailsElement, WebsiteUsageBrowserProxy} from 'chrome://settings/lazy_load.js';
-import {ChooserType, ContentSetting, ContentSettingsTypes, SiteSettingSource, SiteSettingsPrefsBrowserProxyImpl, WebsiteUsageBrowserProxyImpl} from 'chrome://settings/lazy_load.js';
-import {MetricsBrowserProxyImpl, PrivacyElementInteractions, Router, routes} from 'chrome://settings/settings.js';
+import {ChooserType, ContentSetting, ContentSettingsTypes, JavascriptOptimizerSetting, SiteSettingSource, SiteSettingsBrowserProxyImpl, WebsiteUsageBrowserProxyImpl} from 'chrome://settings/lazy_load.js';
+import {loadTimeData, MetricsBrowserProxyImpl, PrivacyElementInteractions, Router, routes} from 'chrome://settings/settings.js';
 import {assertDeepEquals, assertEquals, assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import {flushTasks} from 'chrome://webui-test/polymer_test_util.js';
 import {TestBrowserProxy} from 'chrome://webui-test/test_browser_proxy.js';
-import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
 
 import {TestMetricsBrowserProxy} from './test_metrics_browser_proxy.js';
-import {TestSiteSettingsPrefsBrowserProxy} from './test_site_settings_prefs_browser_proxy.js';
+import {TestSiteSettingsBrowserProxy} from './test_site_settings_browser_proxy.js';
 import type {SiteSettingsPref} from './test_util.js';
 import {createContentSettingTypeToValuePair, createRawChooserException, createRawSiteException, createSiteSettingsPrefs} from './test_util.js';
 
@@ -45,7 +44,7 @@ suite('SiteDetails', function() {
   let prefs: SiteSettingsPref;
 
   /** The mock site settings prefs proxy object to use during test. */
-  let browserProxy: TestSiteSettingsPrefsBrowserProxy;
+  let browserProxy: TestSiteSettingsBrowserProxy;
 
   let testMetricsBrowserProxy: TestMetricsBrowserProxy;
 
@@ -211,8 +210,8 @@ suite('SiteDetails', function() {
                   [createRawSiteException('https://foo.com:443')])]),
         ]);
 
-    browserProxy = new TestSiteSettingsPrefsBrowserProxy();
-    SiteSettingsPrefsBrowserProxyImpl.setInstance(browserProxy);
+    browserProxy = new TestSiteSettingsBrowserProxy();
+    SiteSettingsBrowserProxyImpl.setInstance(browserProxy);
     testMetricsBrowserProxy = new TestMetricsBrowserProxy();
     MetricsBrowserProxyImpl.setInstance(testMetricsBrowserProxy);
     websiteUsageProxy = new TestWebsiteUsageBrowserProxy();
@@ -221,8 +220,9 @@ suite('SiteDetails', function() {
     document.body.innerHTML = window.trustedTypes!.emptyHTML;
   });
 
-  function createSiteDetails(origin: string) {
+  function createSiteDetails(origin: string, prefs?: {[key: string]: any}) {
     const siteDetailsElement = document.createElement('site-details');
+    siteDetailsElement.prefs = prefs;
     document.body.appendChild(siteDetailsElement);
     Router.getInstance().navigateTo(
         routes.SITE_SETTINGS_SITE_DETAILS,
@@ -239,10 +239,10 @@ suite('SiteDetails', function() {
     assertEquals(
         '',
         testElement.shadowRoot!.querySelector(
-                                   '#storedData')!.textContent!.trim());
+                                   '#storedData')!.textContent.trim());
     assertFalse(testElement.$.noStorage.hidden);
     assertTrue(testElement.$.storage.hidden);
-    assertTrue(testElement.$.usage.textContent!.includes('No usage data'));
+    assertTrue(testElement.$.usage.textContent.includes('No usage data'));
 
     // If there is, check the correct amount of usage is specified.
     const usage = '1 KB';
@@ -250,7 +250,7 @@ suite('SiteDetails', function() {
         'usage-total-changed', 'https://foo.com:443', usage, '10 cookies');
     assertTrue(testElement.$.noStorage.hidden);
     assertFalse(testElement.$.storage.hidden);
-    assertTrue(testElement.$.usage.textContent!.includes(usage));
+    assertTrue(testElement.$.usage.textContent.includes(usage));
   });
 
   test('storage gets trashed properly', async function() {
@@ -272,7 +272,7 @@ suite('SiteDetails', function() {
     assertEquals(
         '1 KB',
         testElement.shadowRoot!.querySelector(
-                                   '#storedData')!.textContent!.trim());
+                                   '#storedData')!.textContent.trim());
     assertTrue(testElement.$.noStorage.hidden);
     assertFalse(testElement.$.storage.hidden);
 
@@ -302,7 +302,7 @@ suite('SiteDetails', function() {
     assertEquals(
         '10 cookies',
         testElement.shadowRoot!.querySelector(
-                                   '#numCookies')!.textContent!.trim());
+                                   '#numCookies')!.textContent.trim());
     assertTrue(testElement.$.noStorage.hidden);
     assertFalse(testElement.$.storage.hidden);
 
@@ -367,6 +367,40 @@ suite('SiteDetails', function() {
     });
   });
 
+  test(
+      'javascript optimizer pref sets use-block-if-unfamiliar-label-for-default property',
+      async function() {
+        const testCases = [
+          JavascriptOptimizerSetting.BLOCKED_FOR_UNFAMILIAR_SITES,
+          JavascriptOptimizerSetting.BLOCKED,
+        ];
+
+        for (const testCase of testCases) {
+          const prefs = {
+            generated: {javascript_optimizer: {value: testCase}},
+          };
+          testElement = createSiteDetails('https://foo.com:443', prefs);
+
+          await browserProxy.whenCalled('isOriginValid');
+          await browserProxy.whenCalled('getOriginPermissions');
+
+          const siteDetailsPermissions =
+              testElement.shadowRoot!.querySelectorAll(
+                  'site-details-permission');
+          const javascriptOptimizerPermission =
+              siteDetailsPermissions.values().find(siteDetailsPermission => {
+                return siteDetailsPermission.category ===
+                    ContentSettingsTypes.JAVASCRIPT_OPTIMIZER;
+              });
+
+          assertEquals(
+              (testCase ===
+               JavascriptOptimizerSetting.BLOCKED_FOR_UNFAMILIAR_SITES),
+              javascriptOptimizerPermission!
+                  .useBlockIfUnfamiliarLabelForDefault);
+        }
+      });
+
   test('categories can be hidden', async function() {
     browserProxy.setPrefs(prefs);
     // Only the categories in this list should be visible to the user.
@@ -525,7 +559,7 @@ suite('SiteDetails', function() {
         webUIListenerCallback(
             'usage-total-changed', hostRequested, '1 KB', '10 cookies', '');
         assertTrue(testElement.$.rwsMembership.hidden);
-        assertEquals('', testElement.$.rwsMembership.textContent!.trim());
+        assertEquals('', testElement.$.rwsMembership.textContent.trim());
       });
 
   test(
@@ -547,7 +581,7 @@ suite('SiteDetails', function() {
         assertFalse(testElement.$.rwsMembership.hidden);
         assertEquals(
             'Allowed for 1 foo.com site',
-            testElement.$.rwsMembership.textContent!.trim());
+            testElement.$.rwsMembership.textContent.trim());
         flush();
         // Assert related website set policy is null.
         const rwsPolicy =
@@ -574,7 +608,7 @@ suite('SiteDetails', function() {
         assertFalse(testElement.$.rwsMembership.hidden);
         assertEquals(
             'Allowed for 1 foo.com site',
-            testElement.$.rwsMembership.textContent!.trim());
+            testElement.$.rwsMembership.textContent.trim());
         flush();
         // Assert related website set policy is shown.
         const rwsPolicy =
