@@ -159,52 +159,126 @@ suite('AppStyleUpdater', () => {
     const expectedDefaultBackground = 'rgb(0, 0, 255)';
     const expectedYellowBackground = 'rgb(0, 255, 0)';
     const expectedDarkBackground = 'rgb(0, 255, 255)';
+    const expectedHighContrastBackground = 'rgb(255, 255, 0)';
+    const expectedLowContrastBackground = 'rgb(255, 0, 255)';
+    const expectedSepiaLightBackground = 'rgb(255, 255, 255)';
+    const expectedSepiaDarkBackground = 'rgb(0, 0, 255)';
     const expectedDefaultForeground = 'rgb(255, 0, 0)';
     const expectedYellowForeground = 'rgb(255, 0, 255)';
     const expectedDarkForeground = 'rgb(255, 255, 0)';
+    const expectedHighContrastForeground = 'rgb(0, 0, 0)';
+    const expectedLowContrastForeground = 'rgb(255, 0, 0)';
+    const expectedSepiaLightForeground = 'rgb(0, 255, 0)';
+    const expectedSepiaDarkForeground = 'rgb(0, 0, 255)';
     const expectedDefaultSelectionBackground = 'rgb(255, 255, 255)';
     const expectedYellowCurrentHighlight = 'rgb(0, 0, 0)';
     const expectedDarkCurrentHighlight = 'rgb(5, 5, 100)';
+    const expectedHighContrastCurrentHighlight = 'rgb(5, 100, 5)';
+    const expectedLowContrastCurrentHighlight = 'rgb(100, 5, 5)';
+    const expectedSepiaLightCurrentHighlight = 'rgb(100, 100, 5)';
+    const expectedSepiaDarkCurrentHighlight = 'rgb(100, 5, 100)';
     const expectedDefaultPreviousHighlight = 'rgb(5, 100, 5)';
     const expectedYellowPreviousHighlight = 'rgb(5, 100, 100)';
-    const expectedDarkPreviousHighlight = 'rgb(100, 5, 5)';
+    const expectedDarkPreviousHighlight = 'rgb(100, 100, 100)';
+    const expectedHighContrastPreviousHighlight = 'rgb(100, 255, 255)';
+    const expectedLowContrastPreviousHighlight = 'rgb(255, 100, 255)';
+    const expectedSepiaLightPreviousHighlight = 'rgb(255, 255, 100)';
+    const expectedSepiaDarkPreviousHighlight = 'rgb(100, 100, 255)';
     const expectedDefaultEmptyHeading = 'rgb(100, 5, 100)';
     const expectedDefaultEmptyBody = 'rgb(100, 100, 100)';
     const expectedYellowEmptyBody = 'rgb(6, 6, 37)';
     const expectedDarkEmptyBody = 'rgb(6, 37, 6)';
+    const expectedHighContrastEmptyBody = 'rgb(11, 11, 11)';
+    const expectedLowContrastEmptyBody = 'rgb(11, 11, 12)';
+    const expectedSepiaLightEmptyBody = 'rgb(37, 6, 37)';
+    const expectedSepiaDarkEmptyBody = 'rgb(37, 37, 6)';
     const expectedDefaultLink = 'rgb(6, 37, 37)';
     const expectedYellowLink = 'rgb(37, 6, 6)';
     const expectedDarkLink = 'rgb(37, 6, 37)';
+    const expectedHighContrastLink = 'rgb(6, 37, 6)';
+    const expectedLowContrastLink = 'rgb(6, 37, 37)';
+    const expectedSepiaLightLink = 'rgb(6, 37, 6)';
+    const expectedSepiaDarkLink = 'rgb(37, 6, 37)';
     const expectedDefaultLinkVisited = 'rgb(37, 37, 6)';
     const expectedYellowLinkVisited = 'rgb(37, 37, 37)';
     const expectedDarkLinkVisited = 'rgb(14, 14, 28)';
+    const expectedHighContrastLinkVisited = 'rgb(14, 28, 14)';
+    const expectedLowContrastLinkVisited = 'rgb(28, 14, 14)';
+    const expectedSepiaLightLinkVisited = 'rgb(14, 28, 28)';
+    const expectedSepiaDarkLinkVisited = 'rgb(28, 14, 28)';
     updateStyles({
       '--color-sys-base-container-elevated': expectedDefaultBackground,
       '--color-read-anything-background-yellow': expectedYellowBackground,
       '--color-read-anything-background-dark': expectedDarkBackground,
+      '--color-read-anything-background-high-contrast':
+          expectedHighContrastBackground,
+      '--color-read-anything-background-low-contrast':
+          expectedLowContrastBackground,
+      '--color-read-anything-background-sepia-light':
+          expectedSepiaLightBackground,
+      '--color-read-anything-background-sepia-dark':
+          expectedSepiaDarkBackground,
       '--color-sys-on-surface': expectedDefaultForeground,
       '--color-read-anything-foreground': expectedDefaultEmptyHeading,
       '--color-read-anything-foreground-yellow': expectedYellowForeground,
       '--color-read-anything-foreground-dark': expectedDarkForeground,
+      '--color-read-anything-foreground-high-contrast':
+          expectedHighContrastForeground,
+      '--color-read-anything-foreground-low-contrast':
+          expectedLowContrastForeground,
+      '--color-read-anything-foreground-sepia-light':
+          expectedSepiaLightForeground,
+      '--color-read-anything-foreground-sepia-dark':
+          expectedSepiaDarkForeground,
       '--color-text-selection-background': expectedDefaultSelectionBackground,
       '--color-read-anything-current-read-aloud-highlight-yellow':
           expectedYellowCurrentHighlight,
       '--color-read-anything-current-read-aloud-highlight-dark':
           expectedDarkCurrentHighlight,
+      '--color-read-anything-current-read-aloud-highlight-high-contrast':
+          expectedHighContrastCurrentHighlight,
+      '--color-read-anything-current-read-aloud-highlight-low-contrast':
+          expectedLowContrastCurrentHighlight,
+      '--color-read-anything-current-read-aloud-highlight-sepia-light':
+          expectedSepiaLightCurrentHighlight,
+      '--color-read-anything-current-read-aloud-highlight-sepia-dark':
+          expectedSepiaDarkCurrentHighlight,
       '--color-sys-on-surface-subtle': expectedDefaultPreviousHighlight,
       '--color-read-anything-previous-read-aloud-highlight-yellow':
           expectedYellowPreviousHighlight,
       '--color-read-anything-previous-read-aloud-highlight-dark':
           expectedDarkPreviousHighlight,
+      '--color-read-anything-previous-read-aloud-highlight-high-contrast':
+          expectedHighContrastPreviousHighlight,
+      '--color-read-anything-previous-read-aloud-highlight-low-contrast':
+          expectedLowContrastPreviousHighlight,
+      '--color-read-anything-previous-read-aloud-highlight-sepia-light':
+          expectedSepiaLightPreviousHighlight,
+      '--color-read-anything-previous-read-aloud-highlight-sepia-dark':
+          expectedSepiaDarkPreviousHighlight,
       '--color-side-panel-card-secondary-foreground': expectedDefaultEmptyBody,
       '--google-grey-700': expectedYellowEmptyBody,
       '--google-grey-500': expectedDarkEmptyBody,
       '--color-read-anything-link-default': expectedDefaultLink,
       '--color-read-anything-link-default-yellow': expectedYellowLink,
       '--color-read-anything-link-default-dark': expectedDarkLink,
+      '--color-read-anything-link-default-high-contrast':
+          expectedHighContrastLink,
+      '--color-read-anything-link-default-low-contrast':
+          expectedLowContrastLink,
+      '--color-read-anything-link-default-sepia-light': expectedSepiaLightLink,
+      '--color-read-anything-link-default-sepia-dark': expectedSepiaDarkLink,
       '--color-read-anything-link-visited': expectedDefaultLinkVisited,
       '--color-read-anything-link-visited-yellow': expectedYellowLinkVisited,
       '--color-read-anything-link-visited-dark': expectedDarkLinkVisited,
+      '--color-read-anything-link-visited-high-contrast':
+          expectedHighContrastLinkVisited,
+      '--color-read-anything-link-visited-low-contrast':
+          expectedLowContrastLinkVisited,
+      '--color-read-anything-link-visited-sepia-light':
+          expectedSepiaLightLinkVisited,
+      '--color-read-anything-link-visited-sepia-dark':
+          expectedSepiaDarkLinkVisited,
     });
     chrome.readingMode.onHighlightGranularityChanged(
         chrome.readingMode.autoHighlighting);
@@ -266,6 +340,98 @@ suite('AppStyleUpdater', () => {
         expectedDarkEmptyBody, computeStyle('--sp-empty-state-body-color'));
     assertEquals(expectedDarkLink, computeStyle('--link-color'));
     assertEquals(expectedDarkLinkVisited, computeStyle('--visited-link-color'));
+
+    // Verify high contrast theme colors.
+    updateStyles({'--google-grey-700': expectedHighContrastEmptyBody});
+    chrome.readingMode.colorTheme = chrome.readingMode.highContrastTheme;
+    updater.setTheme();
+    assertStringContains(
+        computeStyle('background'), expectedHighContrastBackground);
+    assertStringContains(computeStyle('color'), expectedHighContrastForeground);
+    assertEquals(
+        expectedHighContrastCurrentHighlight,
+        computeStyle('--current-highlight-bg-color'));
+    assertEquals(
+        expectedHighContrastPreviousHighlight,
+        computeStyle('--previous-highlight-color'));
+    assertEquals(
+        expectedHighContrastForeground,
+        computeStyle('--sp-empty-state-heading-color'));
+    assertEquals(
+        expectedHighContrastEmptyBody,
+        computeStyle('--sp-empty-state-body-color'));
+    assertEquals(expectedHighContrastLink, computeStyle('--link-color'));
+    assertEquals(
+        expectedHighContrastLinkVisited, computeStyle('--visited-link-color'));
+
+    // Verify low contrast theme colors.
+    updateStyles({'--google-grey-700': expectedLowContrastEmptyBody});
+    chrome.readingMode.colorTheme = chrome.readingMode.lowContrastTheme;
+    updater.setTheme();
+    assertStringContains(
+        computeStyle('background'), expectedLowContrastBackground);
+    assertStringContains(computeStyle('color'), expectedLowContrastForeground);
+    assertEquals(
+        expectedLowContrastCurrentHighlight,
+        computeStyle('--current-highlight-bg-color'));
+    assertEquals(
+        expectedLowContrastPreviousHighlight,
+        computeStyle('--previous-highlight-color'));
+    assertEquals(
+        expectedLowContrastForeground,
+        computeStyle('--sp-empty-state-heading-color'));
+    assertEquals(
+        expectedLowContrastEmptyBody,
+        computeStyle('--sp-empty-state-body-color'));
+    assertEquals(expectedLowContrastLink, computeStyle('--link-color'));
+    assertEquals(
+        expectedLowContrastLinkVisited, computeStyle('--visited-link-color'));
+
+    // Verify sepia light theme colors.
+    updateStyles({'--google-grey-700': expectedSepiaLightEmptyBody});
+    chrome.readingMode.colorTheme = chrome.readingMode.sepiaLightTheme;
+    updater.setTheme();
+    assertStringContains(
+        computeStyle('background'), expectedSepiaLightBackground);
+    assertStringContains(computeStyle('color'), expectedSepiaLightForeground);
+    assertEquals(
+        expectedSepiaLightCurrentHighlight,
+        computeStyle('--current-highlight-bg-color'));
+    assertEquals(
+        expectedSepiaLightPreviousHighlight,
+        computeStyle('--previous-highlight-color'));
+    assertEquals(
+        expectedSepiaLightForeground,
+        computeStyle('--sp-empty-state-heading-color'));
+    assertEquals(
+        expectedSepiaLightEmptyBody,
+        computeStyle('--sp-empty-state-body-color'));
+    assertEquals(expectedSepiaLightLink, computeStyle('--link-color'));
+    assertEquals(
+        expectedSepiaLightLinkVisited, computeStyle('--visited-link-color'));
+
+    // Verify sepia dark theme colors.
+    updateStyles({'--google-grey-700': expectedSepiaDarkEmptyBody});
+    chrome.readingMode.colorTheme = chrome.readingMode.sepiaDarkTheme;
+    updater.setTheme();
+    assertStringContains(
+        computeStyle('background'), expectedSepiaDarkBackground);
+    assertStringContains(computeStyle('color'), expectedSepiaDarkForeground);
+    assertEquals(
+        expectedSepiaDarkCurrentHighlight,
+        computeStyle('--current-highlight-bg-color'));
+    assertEquals(
+        expectedSepiaDarkPreviousHighlight,
+        computeStyle('--previous-highlight-color'));
+    assertEquals(
+        expectedSepiaDarkForeground,
+        computeStyle('--sp-empty-state-heading-color'));
+    assertEquals(
+        expectedSepiaDarkEmptyBody,
+        computeStyle('--sp-empty-state-body-color'));
+    assertEquals(expectedSepiaDarkLink, computeStyle('--link-color'));
+    assertEquals(
+        expectedSepiaDarkLinkVisited, computeStyle('--visited-link-color'));
   });
 
   test('setAllTextStyles updates all text styles', () => {
